@@ -81,6 +81,17 @@ public abstract class JsonNode
     @Override
     public int size() { return 0; }
 
+    /**
+     * Convenience method that is functionally same as:
+     *<pre>
+     *    size() == 0
+     *</pre>
+     * for all node types.
+     *
+     * @since 2.10
+     */
+    public boolean isEmpty() { return size() == 0; }
+
     @Override
     public final boolean isValueNode()
     {
@@ -230,6 +241,16 @@ public abstract class JsonNode
         return at(JsonPointer.compile(jsonPtrExpr));
     }
 
+    /**
+     * Helper method used by other methods for traversing the next step
+     * of given path expression, and returning matching value node if any:
+     * if no match, {@code null} is returned.
+     *
+     * @param ptr Path expression to use
+     *
+     * @return Either matching {@link JsonNode} for the first step of path or
+     *    {@code null} if no match (including case that this node is not a container)
+     */
     protected abstract JsonNode _at(JsonPointer ptr);
 
     /*
@@ -311,7 +332,7 @@ public abstract class JsonNode
      * Note, however, that even if this method returns false, it
      * is possible that conversion would be possible from other numeric
      * types -- to check if this is possible, use
-     * {@link #canConvertToInt()} instead.
+     * {@link #canConvertToLong()} instead.
      * 
      * @return True if the value contained by this node is stored as Java <code>long</code>
      */
@@ -393,7 +414,30 @@ public abstract class JsonNode
      * @since 2.0
      */
     public boolean canConvertToLong() { return false; }
-    
+
+    /**
+     * Method that can be used to check whether contained value
+     * is numeric (returns true for {@link #isNumber()}) and
+     * can be losslessly converted to integral number (specifically,
+     * {@link BigInteger} but potentially others, see
+     * {@link #canConvertToInt} and {@link #canConvertToInt}).
+     * Latter part allows floating-point numbers
+     * (for which {@link #isFloatingPointNumber()} returns {@code true})
+     * that do not have fractional part.
+     * Note that "not-a-number" values of {@code double} and {@code float}
+     * will return {@code false} as they can not be converted to matching
+     * integral representations.
+     *
+     * @return True if the value is an actual number with no fractional
+     *    part; false for non-numeric types, NaN representations of floating-point
+     *    numbers, and floating-point numbers with fractional part.
+     *
+     * @since 2.12
+     */
+    public boolean canConvertToExactIntegral() {
+        return isIntegralNumber();
+    }
+
     /*
     /**********************************************************
     /* Public API, straight value access
@@ -481,7 +525,7 @@ public abstract class JsonNode
      *   nodes.
      */
     public long longValue() { return 0L; }
-    
+
     /**
      * Returns 32-bit floating value for this node, <b>if and only if</b>
      * this node is numeric ({@link #isNumber} returns true). For other
@@ -587,7 +631,7 @@ public abstract class JsonNode
      * and 1 (true), and Strings are parsed using default Java language integer
      * parsing rules.
      *<p>
-     * If representation cannot be converted to an long (including structured types
+     * If representation cannot be converted to a long (including structured types
      * like Objects and Arrays),
      * default value of <b>0</b> will be returned; no exceptions are thrown.
      */
@@ -601,7 +645,7 @@ public abstract class JsonNode
      * and 1 (true), and Strings are parsed using default Java language integer
      * parsing rules.
      *<p>
-     * If representation cannot be converted to an long (including structured types
+     * If representation cannot be converted to a long (including structured types
      * like Objects and Arrays),
      * specified <b>defaultValue</b> will be returned; no exceptions are thrown.
      */
@@ -665,6 +709,153 @@ public abstract class JsonNode
         return defaultValue;
     }
 
+    /*
+    /**********************************************************************
+    /* Public API, extended traversal (2.10) with "required()"
+    /**********************************************************************
+     */
+
+    /**
+     * Method that may be called to verify that {@code this} node is NOT so-called
+     * "missing node": that is, one for which {@link #isMissingNode()} returns {@code true}.
+     * If not missing node, {@code this} is returned to allow chaining; otherwise
+     * {@link IllegalArgumentException} is thrown.
+     *
+     * @return {@code this} node to allow chaining
+     *
+     * @throws IllegalArgumentException if this node is "missing node"
+     *
+     * @since 2.10
+     */
+    public <T extends JsonNode> T require() throws IllegalArgumentException {
+        return _this();
+    }
+
+    /**
+     * Method that may be called to verify that {@code this} node is neither so-called
+     * "missing node" (that is, one for which {@link #isMissingNode()} returns {@code true})
+     * nor "null node" (one for which {@link #isNull()} returns {@code true}).
+     * If non-null non-missing node, {@code this} is returned to allow chaining; otherwise
+     * {@link IllegalArgumentException} is thrown.
+     *
+     * @return {@code this} node to allow chaining
+     *
+     * @throws IllegalArgumentException if this node is either "missing node" or "null node"
+     *
+     * @since 2.10
+     */
+    public <T extends JsonNode> T requireNonNull() throws IllegalArgumentException {
+        return _this();
+    }
+
+    /**
+     * Method is functionally equivalent to
+     *{@code
+     *   path(fieldName).required()
+     *}
+     * and can be used to check that this node is an {@code ObjectNode} (that is, represents
+     * JSON Object value) and has value for specified property with key {@code fieldName}
+     * (but note that value may be explicit JSON null value).
+     * If this node is Object Node and has value for specified property, matching value
+     * is returned; otherwise {@link IllegalArgumentException} is thrown.
+     *
+     * @param propertyName Name of property to access
+     *
+     * @return Value of the specified property of this Object node
+     *
+     * @throws IllegalArgumentException if this node is not an Object node or if it does not
+     *   have value for specified property
+     *
+     * @since 2.10
+     */
+    public JsonNode required(String propertyName) throws IllegalArgumentException {
+        return _reportRequiredViolation("Node of type `%s` has no fields", getClass().getName());
+    }
+
+    /**
+     * Method is functionally equivalent to
+     *{@code
+     *   path(index).required()
+     *}
+     * and can be used to check that this node is an {@code ArrayNode} (that is, represents
+     * JSON Array value) and has value for specified {@code index}
+     * (but note that value may be explicit JSON null value).
+     * If this node is Array Node and has value for specified index, value at index
+     * is returned; otherwise {@link IllegalArgumentException} is thrown.
+     *
+     * @param index Index of the value of this Array node to access
+     *
+     * @return Value at specified index of this Array node
+     *
+     * @throws IllegalArgumentException if this node is not an Array node or if it does not
+     *   have value for specified index
+     *
+     * @since 2.10
+     */
+    public JsonNode required(int index) throws IllegalArgumentException {
+        return _reportRequiredViolation("Node of type `%s` has no indexed values", getClass().getName());
+    }
+
+    /**
+     * Method is functionally equivalent to
+     *{@code
+     *   at(pathExpr).required()
+     *}
+     * and can be used to check that there is an actual value node at specified {@link JsonPointer}
+     * starting from {@code this} node
+     * (but note that value may be explicit JSON null value).
+     * If such value node exists it is returned;
+     * otherwise {@link IllegalArgumentException} is thrown.
+     *
+     * @param pathExpr {@link JsonPointer} expression (as String) to use for finding value node
+     *
+     * @return Matching value node for given expression
+     *
+     * @throws IllegalArgumentException if no value node exists at given {@code JSON Pointer} path
+     *
+     * @since 2.10
+     */
+    public JsonNode requiredAt(String pathExpr) throws IllegalArgumentException {
+        return requiredAt(JsonPointer.compile(pathExpr));
+    }
+
+    /**
+     * Method is functionally equivalent to
+     *{@code
+     *   at(path).required()
+     *}
+     * and can be used to check that there is an actual value node at specified {@link JsonPointer}
+     * starting from {@code this} node
+     * (but note that value may be explicit JSON null value).
+     * If such value node exists it is returned;
+     * otherwise {@link IllegalArgumentException} is thrown.
+     *
+     * @param path {@link JsonPointer} expression to use for finding value node
+     *
+     * @return Matching value node for given expression
+     *
+     * @throws IllegalArgumentException if no value node exists at given {@code JSON Pointer} path
+     *
+     * @since 2.10
+     */
+    public final JsonNode requiredAt(final JsonPointer path) throws IllegalArgumentException {
+        JsonPointer currentExpr = path;
+        JsonNode curr = this;
+
+        // Note: copied from `at()`
+        while (true) {
+            if (currentExpr.matches()) {
+                return curr;
+            }
+            curr = curr._at(currentExpr); // lgtm [java/dereferenced-value-may-be-null]
+            if (curr == null) {
+                _reportRequiredViolation("No node at '%s' (unmatched part: '%s')",
+                        path, currentExpr);
+            }
+            currentExpr = currentExpr.tail();
+        }
+    }
+
     /*
     /**********************************************************
     /* Public API, value find / existence check methods
@@ -893,8 +1084,10 @@ public abstract class JsonNode
      * If the node method is called on is not Object node,
      * or if property exists and has value that is not Object node,
      * {@link UnsupportedOperationException} is thrown
+     *<p>
+     * NOTE: since 2.10 has had co-variant return type
      */
-    public JsonNode with(String propertyName) {
+    public <T extends JsonNode> T with(String propertyName) {
         throw new UnsupportedOperationException("JsonNode not of type ObjectNode (but "
                 +getClass().getName()+"), cannot call with() on it");
     }
@@ -906,8 +1099,10 @@ public abstract class JsonNode
      * If the node method is called on is not Object node,
      * or if property exists and has value that is not Array node,
      * {@link UnsupportedOperationException} is thrown
+     *<p>
+     * NOTE: since 2.10 has had co-variant return type
      */
-    public JsonNode withArray(String propertyName) {
+    public <T extends JsonNode> T withArray(String propertyName) {
         throw new UnsupportedOperationException("JsonNode not of type ObjectNode (but "
                 +getClass().getName()+"), cannot call withArray() on it");
     }
@@ -947,10 +1142,10 @@ public abstract class JsonNode
      */
     
     /**
-     * Method that will produce developer-readable representation of the
-     * node; which may <b>or may not</b> be as valid JSON.
-     * If you want valid JSON output (or output formatted using one of
-     * other Jackson supported data formats) make sure to use
+     * Method that will produce (as of Jackson 2.10) valid JSON using
+     * default settings of databind, as String.
+     * If you want other kinds of JSON output (or output formatted using one of
+     * other Jackson-supported data formats) make sure to use
      * {@link ObjectMapper} or {@link ObjectWriter} to serialize an
      * instance, for example:
      *<pre>
@@ -964,6 +1159,16 @@ public abstract class JsonNode
     @Override
     public abstract String toString();
 
+    /**
+     * Alternative to {@link #toString} that will serialize this node using
+     * Jackson default pretty-printer.
+     *
+     * @since 2.10
+     */
+    public String toPrettyString() {
+        return toString();
+    }
+    
     /**
      * Equality for node objects is defined as full (deep) value
      * equality. This means that it is possible to compare complete
@@ -975,4 +1180,25 @@ public abstract class JsonNode
      */
     @Override
     public abstract boolean equals(Object o);
+
+    /*
+    /**********************************************************************
+    /* Helper methods,  for sub-classes
+    /**********************************************************************
+     */
+
+    // @since 2.10
+    @SuppressWarnings("unchecked")
+    protected <T extends JsonNode> T _this() {
+        return (T) this;
+    }
+
+    /**
+     * Helper method that throws {@link IllegalArgumentException} as a result of
+     * violating "required-constraint" for this node (for {@link #required} or related
+     * methods).
+     */
+    protected <T> T _reportRequiredViolation(String msgTemplate, Object...args) {
+        throw new IllegalArgumentException(String.format(msgTemplate, args));
+    }
 }
