@@ -53,6 +53,14 @@ public class EnumDeserializer
 
     protected final Boolean _caseInsensitive;
 
+    /**
+     * Marker flag for cases where we expect actual integral value for Enum,
+     * based on {@code @JsonValue} (and equivalent) annotated accessor.
+     *
+     * @since 2.13
+     */
+    protected final boolean _isFromIntValue;
+
     /**
      * @since 2.9
      */
@@ -63,6 +71,7 @@ public class EnumDeserializer
         _enumsByIndex = byNameResolver.getRawEnums();
         _enumDefaultValue = byNameResolver.getDefaultValue();
         _caseInsensitive = caseInsensitive;
+        _isFromIntValue = byNameResolver.isFromIntValue();
     }
 
     /**
@@ -75,6 +84,7 @@ public class EnumDeserializer
         _enumsByIndex = base._enumsByIndex;
         _enumDefaultValue = base._enumDefaultValue;
         _caseInsensitive = caseInsensitive;
+        _isFromIntValue = base._isFromIntValue;
     }
 
     /**
@@ -84,7 +94,7 @@ public class EnumDeserializer
     public EnumDeserializer(EnumResolver byNameResolver) {
         this(byNameResolver, null);
     }
-    
+
     /**
      * @deprecated Since 2.8
      */
@@ -190,6 +200,13 @@ public class EnumDeserializer
 
         // But let's consider int acceptable as well (if within ordinal range)
         if (p.hasToken(JsonToken.VALUE_NUMBER_INT)) {
+            // 26-Sep-2021, tatu: [databind#1850] Special case where we get "true" integer
+            //    enumeration and should avoid use of {@code Enum.index()}
+            if (_isFromIntValue) {
+                // ... whether to rely on "getText()" returning String, or get number, convert?
+                // For now assume all format backends can produce String:
+                return _fromString(p, ctxt, p.getText());
+            }
             return _fromInteger(p, ctxt, p.getIntValue());
         }
 
@@ -273,6 +290,16 @@ public class EnumDeserializer
     {
         String name = nameOrig.trim();
         if (name.isEmpty()) { // empty or blank
+            // 07-Jun-2021, tatu: [databind#3171] Need to consider Default value first
+            //   (alas there's bit of duplication here)
+            if ((_enumDefaultValue != null)
+                    && ctxt.isEnabled(DeserializationFeature.READ_UNKNOWN_ENUM_VALUES_USING_DEFAULT_VALUE)) {
+                return _enumDefaultValue;
+            }
+            if (ctxt.isEnabled(DeserializationFeature.READ_UNKNOWN_ENUM_VALUES_AS_NULL)) {
+                return null;
+            }
+
             CoercionAction act;
             if (nameOrig.isEmpty()) {
                 act = _findCoercionFromEmptyString(ctxt);
@@ -299,7 +326,8 @@ public class EnumDeserializer
                 if (match != null) {
                     return match;
                 }
-            } else if (!ctxt.isEnabled(DeserializationFeature.FAIL_ON_NUMBERS_FOR_ENUMS)) {
+            } else if (!ctxt.isEnabled(DeserializationFeature.FAIL_ON_NUMBERS_FOR_ENUMS)
+                    && !_isFromIntValue) {
                 // [databind#149]: Allow use of 'String' indexes as well -- unless prohibited (as per above)
                 char c = name.charAt(0);
                 if (c >= '0' && c <= '9') {
@@ -323,11 +351,11 @@ public class EnumDeserializer
                 && ctxt.isEnabled(DeserializationFeature.READ_UNKNOWN_ENUM_VALUES_USING_DEFAULT_VALUE)) {
             return _enumDefaultValue;
         }
-        if (!ctxt.isEnabled(DeserializationFeature.READ_UNKNOWN_ENUM_VALUES_AS_NULL)) {
-            return ctxt.handleWeirdStringValue(_enumClass(), name,
-                    "not one of the values accepted for Enum class: %s",  lookup.keys());
+        if (ctxt.isEnabled(DeserializationFeature.READ_UNKNOWN_ENUM_VALUES_AS_NULL)) {
+            return null;
         }
-        return null;
+        return ctxt.handleWeirdStringValue(_enumClass(), name,
+                "not one of the values accepted for Enum class: %s",  lookup.keys());
     }
 
     protected Object _deserializeOther(JsonParser p, DeserializationContext ctxt) throws IOException
