@@ -8,6 +8,7 @@ import java.net.URI;
 import java.net.URL;
 import java.nio.charset.Charset;
 import java.util.Currency;
+import java.util.IllformedLocaleException;
 import java.util.Locale;
 import java.util.TimeZone;
 import java.util.regex.Pattern;
@@ -170,9 +171,8 @@ public abstract class FromStringDeserializer<T> extends StdScalarDeserializer<T>
             msg = msg + ", problem: "+m2;
         }
         // 05-May-2016, tatu: Unlike most usage, this seems legit, so...
-        JsonMappingException e = ctxt.weirdStringException(text, _valueClass, msg);
-        e.initCause(cause);
-        throw e;
+        throw ctxt.weirdStringException(text, _valueClass, msg)
+            .withCause(cause);
     }
 
     /**
@@ -282,6 +282,8 @@ _coercedTypeDesc());
         // No longer implemented here since 2.12
         //        public final static int STD_STRING_BUILDER = 13;
 
+        protected final static String LOCALE_EXT_MARKER = "_#";
+
         protected final int _kind;
 
         protected Std(Class<?> valueType, int kind) {
@@ -315,20 +317,7 @@ _coercedTypeDesc());
                 // will throw IAE (or its subclass) if malformed
                 return Pattern.compile(value);
             case STD_LOCALE:
-                {
-                    int ix = _firstHyphenOrUnderscore(value);
-                    if (ix < 0) { // single argument
-                        return new Locale(value);
-                    }
-                    String first = value.substring(0, ix);
-                    value = value.substring(ix+1);
-                    ix = _firstHyphenOrUnderscore(value);
-                    if (ix < 0) { // two pieces
-                        return new Locale(first, value);
-                    }
-                    String second = value.substring(0, ix);
-                    return new Locale(first, second, value.substring(ix+1));
-                }
+                return _deserializeLocale(value, ctxt);
             case STD_CHARSET:
                 return Charset.forName(value);
             case STD_TIME_ZONE:
@@ -396,6 +385,64 @@ _coercedTypeDesc());
             }
             return -1;
         }
+
+        private Locale _deserializeLocale(String value, DeserializationContext ctxt)
+            throws IOException
+        {
+            int ix = _firstHyphenOrUnderscore(value);
+            if (ix < 0) { // single argument
+                return new Locale(value);
+            }
+            String first = value.substring(0, ix);
+            value = value.substring(ix+1);
+            ix = _firstHyphenOrUnderscore(value);
+            if (ix < 0) { // two pieces
+                return new Locale(first, value);
+            }
+            String second = value.substring(0, ix);
+            // [databind#3259]: Support for BCP 47 java.util.Locale ser/deser
+            int extMarkerIx = value.indexOf(LOCALE_EXT_MARKER);
+            if (extMarkerIx < 0) {
+                return new Locale(first, second, value.substring(ix+1));
+            }
+            return _deSerializeBCP47Locale(value, ix, first, second, extMarkerIx);
+        }
+
+        private Locale _deSerializeBCP47Locale(String value, int ix, String first, String second,
+                int extMarkerIx)
+        {
+            String third = "";
+            try {
+                // Below condition checks if variant value is present to handle empty variant values such as
+                // en__#Latn_x-ext
+                // _US_#Latn
+                if (extMarkerIx > 0 && extMarkerIx > ix) {
+                    third = value.substring(ix + 1, extMarkerIx);
+                }
+                value = value.substring(extMarkerIx + 2);
+
+                if (value.indexOf('_') < 0 && value.indexOf('-') < 0) {
+                    return new Locale.Builder().setLanguage(first)
+                            .setRegion(second).setVariant(third).setScript(value).build();
+                }
+                if (value.indexOf('_') < 0) {
+                    ix = value.indexOf('-');
+                    return new Locale.Builder().setLanguage(first)
+                            .setRegion(second).setVariant(third)
+                            .setExtension(value.charAt(0), value.substring(ix + 1))
+                            .build();
+                }
+                ix = value.indexOf('_');
+                return new Locale.Builder().setLanguage(first)
+                        .setRegion(second).setVariant(third)
+                        .setScript(value.substring(0, ix))
+                        .setExtension(value.charAt(ix + 1), value.substring(ix + 3))
+                        .build();
+            } catch (IllformedLocaleException ex) {
+                // should we really just swallow the exception?
+                return new Locale(first, second, third);
+            }
+        }
     }
 
     // @since 2.12 to simplify logic a bit: should not use coercions when reading
