@@ -3,13 +3,13 @@ package com.fasterxml.jackson.databind.deser.std;
 import java.io.IOException;
 
 import com.fasterxml.jackson.core.*;
-import com.fasterxml.jackson.databind.DeserializationContext;
-import com.fasterxml.jackson.databind.DeserializationFeature;
+import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.annotation.JacksonStdImpl;
 import com.fasterxml.jackson.databind.jsontype.TypeDeserializer;
+import com.fasterxml.jackson.databind.type.LogicalType;
 
 @JacksonStdImpl
-public final class StringDeserializer extends StdScalarDeserializer<String>
+public class StringDeserializer extends StdScalarDeserializer<String> // non-final since 2.9
 {
     private static final long serialVersionUID = 1L;
 
@@ -17,28 +17,33 @@ public final class StringDeserializer extends StdScalarDeserializer<String>
      * @since 2.2
      */
     public final static StringDeserializer instance = new StringDeserializer();
-    
+
     public StringDeserializer() { super(String.class); }
 
+    @Override // since 2.12
+    public LogicalType logicalType() {
+        return LogicalType.Textual;
+    }
+
     // since 2.6, slightly faster lookups for this very common type
     @Override
     public boolean isCachable() { return true; }
 
+    @Override // since 2.9
+    public Object getEmptyValue(DeserializationContext ctxt) throws JsonMappingException {
+        return "";
+    }
+
     @Override
     public String deserialize(JsonParser p, DeserializationContext ctxt) throws IOException
     {
         if (p.hasToken(JsonToken.VALUE_STRING)) {
             return p.getText();
         }
-        JsonToken t = p.getCurrentToken();
+        JsonToken t = p.currentToken();
         // [databind#381]
-        if ((t == JsonToken.START_ARRAY) && ctxt.isEnabled(DeserializationFeature.UNWRAP_SINGLE_VALUE_ARRAYS)) {
-            p.nextToken();
-            final String parsed = _parseString(p, ctxt);
-            if (p.nextToken() != JsonToken.END_ARRAY) {
-                handleMissingEndArrayForSingle(p, ctxt);
-            }            
-            return parsed;            
+        if (t == JsonToken.START_ARRAY) {
+            return _deserializeFromArray(p, ctxt);
         }
         // need to gracefully handle byte[] data, as base64
         if (t == JsonToken.VALUE_EMBEDDED_OBJECT) {
@@ -52,10 +57,18 @@ public final class StringDeserializer extends StdScalarDeserializer<String>
             // otherwise, try conversion using toString()...
             return ob.toString();
         }
+        // 29-Jun-2020, tatu: New! "Scalar from Object" (mostly for XML)
+        if (t == JsonToken.START_OBJECT) {
+            return ctxt.extractScalarFromObject(p, this, _valueClass);
+        }
         // allow coercions for other scalar types
-        String text = p.getValueAsString();
-        if (text != null) {
-            return text;
+        // 17-Jan-2018, tatu: Related to [databind#1853] avoid FIELD_NAME by ensuring it's
+        //   "real" scalar
+        if (t.isScalarValue()) {
+            String text = p.getValueAsString();
+            if (text != null) {
+                return text;
+            }
         }
         return (String) ctxt.handleUnexpectedToken(_valueClass, p);
     }
@@ -63,7 +76,8 @@ public final class StringDeserializer extends StdScalarDeserializer<String>
     // Since we can never have type info ("natural type"; String, Boolean, Integer, Double):
     // (is it an error to even call this version?)
     @Override
-    public String deserializeWithType(JsonParser p, DeserializationContext ctxt, TypeDeserializer typeDeserializer) throws IOException {
+    public String deserializeWithType(JsonParser p, DeserializationContext ctxt,
+            TypeDeserializer typeDeserializer) throws IOException {
         return deserialize(p, ctxt);
     }
 }
