@@ -1,6 +1,8 @@
 package com.fasterxml.jackson.databind.introspect;
 
-import java.lang.reflect.*;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Member;
+import java.lang.reflect.Type;
 
 import com.fasterxml.jackson.databind.JavaType;
 import com.fasterxml.jackson.databind.util.ClassUtil;
@@ -113,10 +115,12 @@ public final class AnnotatedConstructor
         }
         return types[index];
     }
-    
+
     @Override
     public final Object call() throws Exception {
-        return _constructor.newInstance();
+        // 31-Mar-2021, tatu: Note! This is faster than calling without arguments
+        //   because JDK in its wisdom would otherwise allocate `new Object[0]` to pass
+        return _constructor.newInstance((Object[]) null);
     }
 
     @Override
@@ -176,12 +180,20 @@ public final class AnnotatedConstructor
     public int hashCode() {
         return _constructor.getName().hashCode();
     }
-    
+
     @Override
     public boolean equals(Object o) {
         if (o == this) return true;
-        return ClassUtil.hasClass(o, getClass())
-                && (((AnnotatedConstructor) o)._constructor == _constructor);
+        if (!ClassUtil.hasClass(o, getClass())) {
+            return false;
+        }
+
+        AnnotatedConstructor other = (AnnotatedConstructor) o;
+        if (other._constructor == null) {
+            return _constructor == null;
+        } else {
+            return other._constructor.equals(_constructor);
+        }
     }
 
     /*
