@@ -3,15 +3,12 @@ package com.fasterxml.jackson.databind.jsontype.impl;
 import java.io.IOException;
 
 import com.fasterxml.jackson.annotation.JsonTypeInfo.As;
+
 import com.fasterxml.jackson.core.JsonParser;
 import com.fasterxml.jackson.core.JsonToken;
 import com.fasterxml.jackson.core.util.JsonParserSequence;
-import com.fasterxml.jackson.databind.BeanProperty;
-import com.fasterxml.jackson.databind.DeserializationContext;
-import com.fasterxml.jackson.databind.DeserializationFeature;
-import com.fasterxml.jackson.databind.JavaType;
-import com.fasterxml.jackson.databind.JsonDeserializer;
-import com.fasterxml.jackson.databind.MapperFeature;
+
+import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.jsontype.TypeDeserializer;
 import com.fasterxml.jackson.databind.jsontype.TypeIdResolver;
 import com.fasterxml.jackson.databind.util.TokenBuffer;
@@ -31,6 +28,11 @@ public class AsPropertyTypeDeserializer extends AsArrayTypeDeserializer
 
     protected final As _inclusion;
 
+    // @since 2.12.2 (see [databind#3055]
+    protected final String _msgForMissingId = (_property == null)
+            ? String.format("missing type id property '%s'", _typePropertyName)
+            : String.format("missing type id property '%s' (for POJO property '%s')", _typePropertyName, _property.getName());
+
     /**
      * @since 2.8
      */
@@ -91,7 +93,7 @@ public class AsPropertyTypeDeserializer extends AsArrayTypeDeserializer
              * But this can also be due to some custom handling: so, if "defaultImpl"
              * is defined, it will be asked to handle this case.
              */
-            return _deserializeTypedUsingDefaultImpl(p, ctxt, null);
+            return _deserializeTypedUsingDefaultImpl(p, ctxt, null, _msgForMissingId);
         }
         // Ok, let's try to find the property. But first, need token buffer...
         TokenBuffer tb = null;
@@ -102,23 +104,28 @@ public class AsPropertyTypeDeserializer extends AsArrayTypeDeserializer
             p.nextToken(); // to point to the value
             if (name.equals(_typePropertyName)
                     || (ignoreCase && name.equalsIgnoreCase(_typePropertyName))) { // gotcha!
-                return _deserializeTypedForId(p, ctxt, tb, p.getText());
+                // 09-Sep-2021, tatu: [databind#3271]: Avoid converting null to "null"
+                String typeId = p.getValueAsString();
+                if (typeId != null) {
+                    return _deserializeTypedForId(p, ctxt, tb, typeId);
+                }
             }
             if (tb == null) {
-                tb = new TokenBuffer(p, ctxt);
+                tb = ctxt.bufferForInputBuffering(p);
             }
             tb.writeFieldName(name);
             tb.copyCurrentStructure(p);
         }
-        return _deserializeTypedUsingDefaultImpl(p, ctxt, tb);
+        return _deserializeTypedUsingDefaultImpl(p, ctxt, tb, _msgForMissingId);
     }
 
     protected Object _deserializeTypedForId(JsonParser p, DeserializationContext ctxt,
-            TokenBuffer tb, String typeId) throws IOException {
+            TokenBuffer tb, String typeId) throws IOException
+    {
         JsonDeserializer<Object> deser = _findDeserializer(ctxt, typeId);
         if (_typeIdVisible) { // need to merge id back in JSON input?
             if (tb == null) {
-                tb = new TokenBuffer(p, ctxt);
+                tb = ctxt.bufferForInputBuffering(p);
             }
             tb.writeFieldName(p.currentName());
             tb.writeString(typeId);
@@ -129,15 +136,25 @@ public class AsPropertyTypeDeserializer extends AsArrayTypeDeserializer
             p.clearCurrentToken();
             p = JsonParserSequence.createFlattened(false, tb.asParser(p), p);
         }
-        // Must point to the next value; tb had no current, jp pointed to VALUE_STRING:
-        p.nextToken(); // to skip past String value
+        if (p.currentToken() != JsonToken.END_OBJECT) {
+            // Must point to the next value; tb had no current, p pointed to VALUE_STRING:
+            p.nextToken(); // to skip past String value
+        }
         // deserializer should take care of closing END_OBJECT as well
         return deser.deserialize(p, ctxt);
     }
 
-    // off-lined to keep main method lean and mean...
+    @Deprecated // since 2.12.2 (remove from 2.14 or later)
     protected Object _deserializeTypedUsingDefaultImpl(JsonParser p,
-            DeserializationContext ctxt, TokenBuffer tb) throws IOException
+            DeserializationContext ctxt, TokenBuffer tb) throws IOException {
+        return _deserializeTypedUsingDefaultImpl(p, ctxt, tb, null);
+    }
+
+    // off-lined to keep main method lean and mean...
+    // @since 2.12.2 (last arg added)
+    protected Object _deserializeTypedUsingDefaultImpl(JsonParser p,
+            DeserializationContext ctxt, TokenBuffer tb, String priorFailureMsg)
+        throws IOException
     {
         // May have default implementation to use
         // 13-Oct-2020, tatu: As per [databind#2775], need to be careful to
@@ -165,13 +182,7 @@ public class AsPropertyTypeDeserializer extends AsArrayTypeDeserializer
         // genuine, or faked for "dont fail on bad type id")
         JsonDeserializer<Object> deser = _findDefaultImplDeserializer(ctxt);
         if (deser == null) {
-            String msg = String.format("missing type id property '%s'",
-                    _typePropertyName);
-            // even better, may know POJO property polymorphic value would be assigned to
-            if (_property != null) {
-                msg = String.format("%s (for POJO property '%s')", msg, _property.getName());
-            }
-            JavaType t = _handleMissingTypeId(ctxt, msg);
+            JavaType t = _handleMissingTypeId(ctxt, priorFailureMsg);
             if (t == null) {
                 // 09-Mar-2017, tatu: Is this the right thing to do?
                 return null;
