@@ -6,9 +6,11 @@ import java.lang.reflect.*;
 
 import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.JavaType;
+import com.fasterxml.jackson.databind.JsonNode;
 import com.fasterxml.jackson.databind.util.ArrayBuilders;
 import com.fasterxml.jackson.databind.util.ClassUtil;
 import com.fasterxml.jackson.databind.util.LRUMap;
+import com.fasterxml.jackson.databind.util.LookupCache;
 
 /**
  * Class used for creating concrete {@link JavaType} instances,
@@ -31,7 +33,7 @@ import com.fasterxml.jackson.databind.util.LRUMap;
  *</pre>
  */
 @SuppressWarnings({"rawtypes" })
-public final class TypeFactory
+public class TypeFactory // note: was final in 2.9, removed from 2.10
     implements java.io.Serializable
 {
     private static final long serialVersionUID = 1L;
@@ -63,6 +65,7 @@ public final class TypeFactory
     private final static Class<?> CLS_COMPARABLE = Comparable.class;
     private final static Class<?> CLS_CLASS = Class.class;
     private final static Class<?> CLS_ENUM = Enum.class;
+    private final static Class<?> CLS_JSON_NODE = JsonNode.class; // since 2.10
 
     private final static Class<?> CLS_BOOL = Boolean.TYPE;
     private final static Class<?> CLS_INT = Integer.TYPE;
@@ -109,12 +112,20 @@ public final class TypeFactory
      */
     protected final static SimpleType CORE_TYPE_CLASS = new SimpleType(CLS_CLASS);
 
+    /**
+     * Cache {@link JsonNode} because it is no critical path of simple tree model
+     * reading and does not have things to override
+     *
+     * @since 2.10
+     */
+    protected final static SimpleType CORE_TYPE_JSON_NODE = new SimpleType(CLS_JSON_NODE);
+
     /**
      * Since type resolution can be expensive (specifically when resolving
      * actual generic types), we will use small cache to avoid repetitive
      * resolution of core types
      */
-    protected final LRUMap<Object,JavaType> _typeCache;
+    protected final LookupCache<Object,JavaType> _typeCache;
 
     /*
     /**********************************************************
@@ -142,15 +153,24 @@ public final class TypeFactory
      */
 
     private TypeFactory() {
-        this(null);
+        this((LookupCache<Object,JavaType>) null);
     }
 
     /**
      * @since 2.8
+     * @deprecated Since 2.12
      */
+    @Deprecated // since 2.12
     protected TypeFactory(LRUMap<Object,JavaType> typeCache) {
+        this((LookupCache<Object,JavaType>) typeCache);
+    }
+
+    /**
+     * @since 2.12
+     */
+    protected TypeFactory(LookupCache<Object,JavaType> typeCache) {
         if (typeCache == null) {
-            typeCache = new LRUMap<Object,JavaType>(16, 200);
+            typeCache = new LRUMap<>(16, 200);
         }
         _typeCache = typeCache;
         _parser = new TypeParser(this);
@@ -158,11 +178,24 @@ public final class TypeFactory
         _classLoader = null;
     }
 
+    /**
+     * @deprecated Since 2.12
+     */
+    @Deprecated // since 2.12
     protected TypeFactory(LRUMap<Object,JavaType> typeCache, TypeParser p,
             TypeModifier[] mods, ClassLoader classLoader)
+    {
+        this((LookupCache<Object,JavaType>) typeCache, p, mods, classLoader);
+    }
+
+    /**
+     * @since 2.12
+     */
+    protected TypeFactory(LookupCache<Object,JavaType> typeCache, TypeParser p,
+                          TypeModifier[] mods, ClassLoader classLoader)
     {
         if (typeCache == null) {
-            typeCache = new LRUMap<Object,JavaType>(16, 200);
+            typeCache = new LRUMap<>(16, 200);
         }
         _typeCache = typeCache;
         // As per [databind#894] must ensure we have back-linkage from TypeFactory:
@@ -171,9 +204,14 @@ public final class TypeFactory
         _classLoader = classLoader;
     }
 
+    /**
+     * "Mutant factory" method which will construct a new instance with specified
+     * {@link TypeModifier} added as the first modifier to call (in case there
+     * are multiple registered).
+     */
     public TypeFactory withModifier(TypeModifier mod) 
     {
-        LRUMap<Object,JavaType> typeCache = _typeCache;
+        LookupCache<Object,JavaType> typeCache = _typeCache;
         TypeModifier[] mods;
         if (mod == null) { // mostly for unit tests
             mods = null;
@@ -182,12 +220,20 @@ public final class TypeFactory
             typeCache = null;
         } else if (_modifiers == null) {
             mods = new TypeModifier[] { mod };
+            // 29-Jul-2019, tatu: Actually I think we better clear cache in this case
+            //    as well to ensure no leakage occurs (see [databind#2395])
+            typeCache = null;
         } else {
+            // but may keep existing cache otherwise
             mods = ArrayBuilders.insertInListNoDup(_modifiers, mod);
         }
         return new TypeFactory(typeCache, _parser, mods, _classLoader);
     }
 
+    /**
+     * "Mutant factory" method which will construct a new instance with specified
+     * {@link ClassLoader} to use by {@link #findClass}.
+     */
     public TypeFactory withClassLoader(ClassLoader classLoader) {
         return new TypeFactory(_typeCache, _parser, _modifiers, classLoader);
     }
@@ -198,11 +244,24 @@ public final class TypeFactory
      * bigger maximum size.
      *
      * @since 2.8
+     * @deprecated Since 2.12
      */
+    @Deprecated // since 2.12
     public TypeFactory withCache(LRUMap<Object,JavaType> cache)  {
         return new TypeFactory(cache, _parser, _modifiers, _classLoader);
     }
 
+    /**
+     * Mutant factory method that will construct new {@link TypeFactory} with
+     * identical settings except for different cache; most likely one with
+     * bigger maximum size.
+     *
+     * @since 2.12
+     */
+    public TypeFactory withCache(LookupCache<Object,JavaType> cache)  {
+        return new TypeFactory(cache, _parser, _modifiers, _classLoader);
+    }
+
     /**
      * Method used to access the globally shared instance, which has
      * no custom configuration. Used by <code>ObjectMapper</code> to
@@ -217,7 +276,7 @@ public final class TypeFactory
      * if you know there is a problem with retention of type definitions;
      * the most likely (and currently only known) problem is retention
      * of {@link Class} instances via {@link JavaType} reference.
-     * 
+     *
      * @since 2.4.1
      */
     public void clearCache() {
@@ -281,7 +340,7 @@ public final class TypeFactory
         Throwable prob = null;
         ClassLoader loader = this.getClassLoader();
         if (loader == null) {
-            loader = 	Thread.currentThread().getContextClassLoader();
+            loader = Thread.currentThread().getContextClassLoader();
         }
         if (loader != null) {
             try {
@@ -336,15 +395,45 @@ public final class TypeFactory
      * Can be used, for example, to get equivalent of "HashMap&lt;String,Integer&gt;"
      * from "Map&lt;String,Integer&gt;" by giving <code>HashMap.class</code>
      * as subclass.
+     * Short-cut for:
+     *<pre>
+     * constructSpecializedType(baseType, subclass, class);
+     *</pre>
+     * that is, will use "strict" compatibility checking, usually used for
+     * deserialization purposes (but often not for serialization).
      */
     public JavaType constructSpecializedType(JavaType baseType, Class<?> subclass)
+        throws IllegalArgumentException
+    {
+        return constructSpecializedType(baseType, subclass, false);
+    }
+
+    /**
+     * Factory method for creating a subtype of given base type, as defined
+     * by specified subclass; but retaining generic type information if any.
+     * Can be used, for example, to get equivalent of "HashMap&lt;String,Integer&gt;"
+     * from "Map&lt;String,Integer&gt;" by giving <code>HashMap.class</code>
+     * as subclass.
+     * 
+     * @param baseType Declared base type with resolved type parameters
+     * @param subclass Runtime subtype to use for resolving
+     * @param relaxedCompatibilityCheck Whether checking for type-assignment compatibility
+     *    should be "relaxed" ({@code true}) or "strict" ({@code false}): typically
+     *    serialization uses relaxed, deserialization strict checking.
+     *
+     * @return Resolved sub-type
+     *
+     * @since 2.11
+     */
+    public JavaType constructSpecializedType(JavaType baseType, Class<?> subclass,
+            boolean relaxedCompatibilityCheck)
+        throws IllegalArgumentException
     {
         // simple optimization to avoid costly introspection if type-erased type does NOT differ
         final Class<?> rawBase = baseType.getRawClass();
         if (rawBase == subclass) {
             return baseType;
         }
-
         JavaType newType;
 
         // also: if we start from untyped, not much to save
@@ -354,17 +443,13 @@ public final class TypeFactory
                 break;
             }
             if (!rawBase.isAssignableFrom(subclass)) {
-                throw new IllegalArgumentException(String.format(
-                        "Class %s not subtype of %s", subclass.getName(), baseType));
+                throw new IllegalArgumentException(String.format("Class %s not subtype of %s",
+                        ClassUtil.nameOf(subclass), ClassUtil.getTypeDescription(baseType)
+                ));
             }
             // A few special cases where we can simplify handling:
 
-            // (1) Original target type has no generics -- just resolve subtype
-            if (baseType.getBindings().isEmpty()) {
-                newType = _fromClass(null, subclass, EMPTY_BINDINGS);
-                break;
-            }
-            // (2) A small set of "well-known" List/Map subtypes where can take a short-cut
+            // (1) A small set of "well-known" List/Map subtypes where can take a short-cut
             if (baseType.isContainerType()) {
                 if (baseType.isMapLikeType()) {
                     if ((subclass == HashMap.class)
@@ -391,6 +476,12 @@ public final class TypeFactory
                     }
                 }
             }
+            // (2) Original target type has no generics -- just resolve subtype
+            if (baseType.getBindings().isEmpty()) {
+                newType = _fromClass(null, subclass, EMPTY_BINDINGS);
+                break;
+            }
+
             // (3) Sub-class does not take type parameters -- just resolve subtype
             int typeParamCount = subclass.getTypeParameters().length;
             if (typeParamCount == 0) {
@@ -398,7 +489,8 @@ public final class TypeFactory
                 break;
             }
             // (4) If all else fails, do the full traversal using placeholders
-            TypeBindings tb = _bindingsForSubtype(baseType, typeParamCount, subclass);
+            TypeBindings tb = _bindingsForSubtype(baseType, typeParamCount,
+                    subclass, relaxedCompatibilityCheck);
             newType = _fromClass(null, subclass, tb);
 
         } while (false);
@@ -409,7 +501,8 @@ public final class TypeFactory
         return newType;
     }
 
-    private TypeBindings _bindingsForSubtype(JavaType baseType, int typeParamCount, Class<?> subclass)
+    private TypeBindings _bindingsForSubtype(JavaType baseType, int typeParamCount,
+            Class<?> subclass, boolean relaxedCompatibilityCheck)
     {
         PlaceholderForType[] placeholders = new PlaceholderForType[typeParamCount];
         for (int i = 0; i < typeParamCount; ++i) {
@@ -428,8 +521,12 @@ public final class TypeFactory
         // and traverse type hierarchies to both verify and to resolve placeholders
         String error = _resolveTypePlaceholders(baseType, baseWithPlaceholders);
         if (error != null) {
-            throw new IllegalArgumentException("Failed to specialize base type "+baseType.toCanonical()+" as "
-                    +subclass.getName()+", problem: "+error);
+            // 28-Mar-2020, tatu: As per [databind#2632], need to ignore the issue in
+            //   some cases. For now, just fully ignore; may need to refine in future
+            if (!relaxedCompatibilityCheck) {
+                throw new IllegalArgumentException("Failed to specialize base type "+baseType.toCanonical()+" as "
+                        +subclass.getName()+", problem: "+error);
+            }
         }
 
         final JavaType[] typeParams = new JavaType[typeParamCount];
@@ -451,9 +548,12 @@ public final class TypeFactory
     {
         List<JavaType> expectedTypes = sourceType.getBindings().getTypeParameters();
         List<JavaType> actualTypes = actualType.getBindings().getTypeParameters();
-        for (int i = 0, len = expectedTypes.size(); i < len; ++i) {
+
+        final int actCount = actualTypes.size();
+
+        for (int i = 0, expCount = expectedTypes.size(); i < expCount; ++i) {
             JavaType exp = expectedTypes.get(i);
-            JavaType act = actualTypes.get(i);
+            JavaType act = (i < actCount) ? actualTypes.get(i) : unknownType();
 
             if (!_verifyAndResolvePlaceholders(exp, act)) {
                 // 14-May-2018, tatu: As per [databind#2034] it seems we better relax assignment
@@ -465,8 +565,11 @@ public final class TypeFactory
                 // 19-Apr-2018, tatu: Hack for [databind#1964] -- allow type demotion
                 //    for `java.util.Map` key type if (and only if) target type is
                 //    `java.lang.Object`
+                // 19-Aug-2019, tatu: Further, allow for all Map-like types, with assumption
+                //    first argument would be key; initially just because Scala Maps have
+                //    some issues (see [databind#2422])
                 if (i == 0) {
-                    if (sourceType.hasRawClass(Map.class)
+                    if (sourceType.isMapLikeType()
                             && act.hasRawClass(Object.class)) {
                         continue;
                     }
@@ -479,7 +582,7 @@ public final class TypeFactory
                     }
                 }
                 return String.format("Type parameter #%d/%d differs; can not specialize %s with %s",
-                        (i+1), len, exp.toCanonical(), act.toCanonical());
+                        (i+1), expCount, exp.toCanonical(), act.toCanonical());
             }
         }
         return null;
@@ -620,10 +723,10 @@ public final class TypeFactory
         }
         return type1;
     }
-    
+
     /*
     /**********************************************************
-    /* Public factory methods
+    /* Public general-purpose factory methods
     /**********************************************************
      */
 
@@ -631,10 +734,6 @@ public final class TypeFactory
         return _fromAny(null, type, EMPTY_BINDINGS);
     }
 
-    public JavaType constructType(Type type, TypeBindings bindings) {
-        return _fromAny(null, type, bindings);
-    }
-    
     public JavaType constructType(TypeReference<?> typeRef)
     {
         // 19-Oct-2015, tatu: Simpler variant like so should work
@@ -659,6 +758,53 @@ public final class TypeFactory
         */
     }
 
+    /**
+     * Method to call when resolving types of {@link java.lang.reflect.Member}s
+     * like Fields, Methods and Constructor parameters and there is a
+     * {@link TypeBindings} (that describes binding of type parameters within
+     * context) to pass.
+     * This is typically used only by code in databind itself.
+     * 
+     * @param type Type of a {@link java.lang.reflect.Member} to resolve
+     * @param contextBindings Type bindings from the context, often class in which
+     *     member declared but may be subtype of that type (to bind actual bound
+     *     type parametrers). Not used if {@code type} is of type {@code Class<?>}.
+     *
+     * @return Fully resolve type
+     *
+     * @since 2.12 as replacement for deprecated {@link #constructType(Type, TypeBindings)} 
+     */
+    public JavaType resolveMemberType(Type type, TypeBindings contextBindings) {
+        return _fromAny(null, type, contextBindings);
+    }
+
+    /*
+    /**********************************************************
+    /* Deprecated public factory methods
+    /**********************************************************
+     */
+
+    /**
+     * Method that you very likely should NOT be using -- you need to know a lot
+     * about internal details of {@link TypeBindings} and even then it will probably
+     * not do what you want.
+     * Usually you would instead want to call one of {@code constructXxxType()}
+     * methods (where {@code Xxx} would be "Array", "Collection[Like]", "Map[Like]"
+     * or "Parametric").
+     *
+     * @deprecated Since 2.12
+     */
+    @Deprecated // since 2.12
+    public JavaType constructType(Type type, TypeBindings bindings) {
+        // 15-Jun-2020, tatu: To resolve (parts of) [databind#2796], need to
+        //    call _fromClass() directly if we get `Class` argument
+        if (type instanceof Class<?>) {
+            JavaType resultType = _fromClass(null, (Class<?>) type, bindings);
+            return _applyModifiers(type, resultType);
+        }
+        return _fromAny(null, type, bindings);
+    }
+
     /**
      * @deprecated Since 2.7 (accidentally removed in 2.7.0; added back in 2.7.1)
      */
@@ -807,8 +953,7 @@ public final class TypeFactory
     /**
      * Method for constructing a {@link MapType} instance
      *<p>
-     * NOTE: type modifiers are NOT called on constructed type itself; but are called
-     * for contained types.
+     * NOTE: type modifiers are NOT called on constructed type itself.
      */
     public MapType constructMapType(Class<? extends Map> mapClass, JavaType keyType, JavaType valueType) {
         TypeBindings bindings = TypeBindings.createIfNeeded(mapClass, new JavaType[] { keyType, valueType });
@@ -848,8 +993,7 @@ public final class TypeFactory
     /**
      * Method for constructing a {@link MapLikeType} instance
      *<p>
-     * NOTE: type modifiers are NOT called on constructed type itself; but are called
-     * for contained types.
+     * NOTE: type modifiers are NOT called on constructed type itself.
      */
     public MapLikeType constructMapLikeType(Class<?> mapClass, JavaType keyType, JavaType valueType) {
         // 19-Oct-2015, tatu: Allow case of no-type-variables, since it seems likely to be
@@ -865,7 +1009,7 @@ public final class TypeFactory
     /**
      * Method for constructing a type instance with specified parameterization.
      *<p>
-     * NOTE: was briefly deprecated for 2.6.
+     * NOTE: type modifiers are NOT called on constructed type itself.
      */
     public JavaType constructSimpleType(Class<?> rawType, JavaType[] parameterTypes) {
         return _fromClass(null, rawType, TypeBindings.create(rawType, parameterTypes));
@@ -886,11 +1030,17 @@ public final class TypeFactory
     } 
 
     /**
+     * Method for constructing a {@link ReferenceType} instance with given type parameter
+     * (type MUST take one and only one type parameter)
+     *<p>
+     * NOTE: type modifiers are NOT called on constructed type itself.
+     *
      * @since 2.6
      */
     public JavaType constructReferenceType(Class<?> rawType, JavaType referredType)
     {
-        return ReferenceType.construct(rawType, null, // no bindings
+        return ReferenceType.construct(rawType,
+                TypeBindings.create(rawType, referredType), // [databind#2091]
                 null, null, // or super-class, interfaces?
                 referredType);
     }
@@ -915,26 +1065,16 @@ public final class TypeFactory
     /**
      * Factory method for constructing {@link JavaType} that
      * represents a parameterized type. For example, to represent
-     * type <code>List&lt;Set&lt;Integer>></code>, you could
+     * type {@code List<Set<Integer>>}, you could
      * call
      *<pre>
-     *  JavaType inner = TypeFactory.constructParametricType(Set.class, Set.class, Integer.class);
-     *  return TypeFactory.constructParametricType(ArrayList.class, List.class, inner);
+     *  JavaType inner = TypeFactory.constructParametricType(Set.class, Integer.class);
+     *  return TypeFactory.constructParametricType(List.class, inner);
      *</pre>
      *<p>
-     * The reason for first two arguments to be separate is that parameterization may
-     * apply to a super-type. For example, if generic type was instead to be
-     * constructed for <code>ArrayList&lt;Integer></code>, the usual call would be:
-     *<pre>
-     *  TypeFactory.constructParametricType(ArrayList.class, List.class, Integer.class);
-     *</pre>
-     * since parameterization is applied to {@link java.util.List}.
-     * In most cases distinction does not matter, but there are types where it does;
-     * one such example is parameterization of types that implement {@link java.util.Iterator}.
-     *<p>
-     * NOTE: type modifiers are NOT called on constructed type.
+     * NOTE: since 2.11.2 {@link TypeModifier}s ARE called on result (fix for [databind#2796])
      * 
-     * @param parametrized Actual full type
+     * @param parametrized Type-erased type to parameterize
      * @param parameterClasses Type parameters to apply
      *
      * @since 2.5 NOTE: was briefly deprecated for 2.6
@@ -951,38 +1091,51 @@ public final class TypeFactory
     /**
      * Factory method for constructing {@link JavaType} that
      * represents a parameterized type. For example, to represent
-     * type <code>List&lt;Set&lt;Integer>></code>, you could
-     * call
+     * type {@code List<Set<Integer>>}, you could
      *<pre>
-     *  JavaType inner = TypeFactory.constructParametricType(Set.class, Set.class, Integer.class);
-     *  return TypeFactory.constructParametricType(ArrayList.class, List.class, inner);
+     *  JavaType inner = TypeFactory.constructParametricType(Set.class, Integer.class);
+     *  return TypeFactory.constructParametricType(List.class, inner);
      *</pre>
      *<p>
-     * The reason for first two arguments to be separate is that parameterization may
-     * apply to a super-type. For example, if generic type was instead to be
-     * constructed for <code>ArrayList&lt;Integer></code>, the usual call would be:
-     *<pre>
-     *  TypeFactory.constructParametricType(ArrayList.class, List.class, Integer.class);
-     *</pre>
-     * since parameterization is applied to {@link java.util.List}.
-     * In most cases distinction does not matter, but there are types where it does;
-     * one such example is parameterization of types that implement {@link java.util.Iterator}.
-     *<p>
-     * NOTE: type modifiers are NOT called on constructed type.
-     * 
+     * NOTE: since 2.11.2 {@link TypeModifier}s ARE called on result (fix for [databind#2796])
+     *
      * @param rawType Actual type-erased type
      * @param parameterTypes Type parameters to apply
-     * 
-     * @since 2.5 NOTE: was briefly deprecated for 2.6
+     *
+     * @return Fully resolved type for given base type and type parameters
      */
     public JavaType constructParametricType(Class<?> rawType, JavaType... parameterTypes)
     {
-        return _fromClass(null, rawType, TypeBindings.create(rawType, parameterTypes));
+        return constructParametricType(rawType, TypeBindings.create(rawType, parameterTypes));
     }
 
     /**
-     * @since 2.5 -- but will probably deprecated in 2.7 or 2.8 (not needed with 2.7)
+     * Factory method for constructing {@link JavaType} that
+     * represents a parameterized type. The type's parameters are
+     * specified as an instance of {@link TypeBindings}. This
+     * is useful if you already have the type's parameters such
+     * as those found on {@link JavaType}. For example, you could call
+     * <pre>
+     *   return TypeFactory.constructParametricType(ArrayList.class, javaType.getBindings());
+     * </pre>
+     * This effectively applies the parameterized types from one
+     * {@link JavaType} to another class.
      *
+     * @param rawType Actual type-erased type
+     * @param parameterTypes Type bindings for the raw type
+     *
+     * @since 2.12
+     */
+    public JavaType constructParametricType(Class<?> rawType, TypeBindings parameterTypes)
+    {
+        // 16-Jul-2020, tatu: Since we do not call `_fromAny()`, need to make
+        //   sure `TypeModifier`s are applied:
+        JavaType resultType =  _fromClass(null, rawType, parameterTypes);
+        return _applyModifiers(rawType, resultType);
+    }
+
+    /**
+     * @since 2.5
      * @deprecated since 2.9 Use {@link #constructParametricType(Class,JavaType...)} instead
      */
     @Deprecated
@@ -993,8 +1146,7 @@ public final class TypeFactory
     }
 
     /**
-     * @since 2.5 -- but will probably deprecated in 2.7 or 2.8 (not needed with 2.7)
-     *
+     * @since 2.5
      * @deprecated since 2.9 Use {@link #constructParametricType(Class,Class...)} instead
      */
     @Deprecated
@@ -1088,7 +1240,8 @@ public final class TypeFactory
         } else {
             List<JavaType> typeParams = bindings.getTypeParameters();
             // ok to have no types ("raw")
-            switch (typeParams.size()) {
+            final int pc = typeParams.size();
+            switch (pc) {
             case 0: // acceptable?
                 kt = vt = _unknownType();
                 break;
@@ -1097,7 +1250,9 @@ public final class TypeFactory
                 vt = typeParams.get(1);
                 break;
             default:
-                throw new IllegalArgumentException("Strange Map type "+rawClass.getName()+": cannot determine type parameters");
+                throw new IllegalArgumentException(String.format(
+"Strange Map type %s with %d type parameter%s (%s), can not resolve",
+ClassUtil.nameOf(rawClass), pc, (pc == 1) ? "" : "s", bindings));
             }
         }
         return MapType.construct(rawClass, bindings, superClass, superInterfaces, kt, vt);
@@ -1192,6 +1347,7 @@ public final class TypeFactory
         } else {
             if (clz == CLS_STRING) return CORE_TYPE_STRING;
             if (clz == CLS_OBJECT) return CORE_TYPE_OBJECT; // since 2.7
+            if (clz == CLS_JSON_NODE) return CORE_TYPE_JSON_NODE; // since 2.10
         }
         return null;
     }
@@ -1207,52 +1363,58 @@ public final class TypeFactory
      * as Java typing returned from <code>getGenericXxx</code> methods
      * (usually for a return or argument type).
      */
-    protected JavaType _fromAny(ClassStack context, Type type, TypeBindings bindings)
+    protected JavaType _fromAny(ClassStack context, Type srcType, TypeBindings bindings)
     {
         JavaType resultType;
 
         // simple class?
-        if (type instanceof Class<?>) {
+        if (srcType instanceof Class<?>) {
             // Important: remove possible bindings since this is type-erased thingy
-            resultType = _fromClass(context, (Class<?>) type, EMPTY_BINDINGS);
+            resultType = _fromClass(context, (Class<?>) srcType, EMPTY_BINDINGS);
         }
         // But if not, need to start resolving.
-        else if (type instanceof ParameterizedType) {
-            resultType = _fromParamType(context, (ParameterizedType) type, bindings);
+        else if (srcType instanceof ParameterizedType) {
+            resultType = _fromParamType(context, (ParameterizedType) srcType, bindings);
         }
-        else if (type instanceof JavaType) { // [databind#116]
+        else if (srcType instanceof JavaType) { // [databind#116]
             // no need to modify further if we already had JavaType
-            return (JavaType) type;
+            return (JavaType) srcType;
         }
-        else if (type instanceof GenericArrayType) {
-            resultType = _fromArrayType(context, (GenericArrayType) type, bindings);
+        else if (srcType instanceof GenericArrayType) {
+            resultType = _fromArrayType(context, (GenericArrayType) srcType, bindings);
         }
-        else if (type instanceof TypeVariable<?>) {
-            resultType = _fromVariable(context, (TypeVariable<?>) type, bindings);
+        else if (srcType instanceof TypeVariable<?>) {
+            resultType = _fromVariable(context, (TypeVariable<?>) srcType, bindings);
         }
-        else if (type instanceof WildcardType) {
-            resultType = _fromWildcard(context, (WildcardType) type, bindings);
+        else if (srcType instanceof WildcardType) {
+            resultType = _fromWildcard(context, (WildcardType) srcType, bindings);
         } else {
             // sanity check
-            throw new IllegalArgumentException("Unrecognized Type: "+((type == null) ? "[null]" : type.toString()));
+            throw new IllegalArgumentException("Unrecognized Type: "+((srcType == null) ? "[null]" : srcType.toString()));
         }
-        /* 21-Feb-2016, nateB/tatu: as per [databind#1129] (applied for 2.7.2),
-         *   we do need to let all kinds of types to be refined, esp. for Scala module.
-         */
-        if (_modifiers != null) {
-            TypeBindings b = resultType.getBindings();
-            if (b == null) {
-                b = EMPTY_BINDINGS;
-            }
-            for (TypeModifier mod : _modifiers) {
-                JavaType t = mod.modifyType(resultType, type, b, this);
-                if (t == null) {
-                    throw new IllegalStateException(String.format(
-                            "TypeModifier %s (of type %s) return null for type %s",
-                            mod, mod.getClass().getName(), resultType));
-                }
-                resultType = t;
+        // 21-Feb-2016, nateB/tatu: as per [databind#1129] (applied for 2.7.2),
+        //   we do need to let all kinds of types to be refined, esp. for Scala module.
+        return _applyModifiers(srcType, resultType);
+    }
+
+    protected JavaType _applyModifiers(Type srcType, JavaType resolvedType)
+    {
+        if (_modifiers == null) {
+            return resolvedType;
+        }
+        JavaType resultType = resolvedType;
+        TypeBindings b = resultType.getBindings();
+        if (b == null) {
+            b = EMPTY_BINDINGS;
+        }
+        for (TypeModifier mod : _modifiers) {
+            JavaType t = mod.modifyType(resultType, srcType, b, this);
+            if (t == null) {
+                throw new IllegalStateException(String.format(
+                        "TypeModifier %s (of type %s) return null for type %s",
+                        mod, mod.getClass().getName(), resultType));
             }
+            resultType = t;
         }
         return resultType;
     }
@@ -1380,7 +1542,6 @@ public final class TypeFactory
         if (bindings == null) {
             bindings = EMPTY_BINDINGS;
         }
-        
         // Quite simple when we resolving exact class/interface; start with that
         if (rawType == Map.class) {
             return _mapType(rawType, bindings, superClass, superInterfaces);
@@ -1466,7 +1627,9 @@ public final class TypeFactory
     {
         // ideally should find it via bindings:
         final String name = var.getName();
-if (bindings == null) throw new Error("No Bindings!");
+        if (bindings == null) {
+            throw new IllegalArgumentException("Null `bindings` passed (type variable \""+name+"\")");
+        }
         JavaType type = bindings.findBoundType(name);
         if (type != null) {
             return type;
@@ -1478,7 +1641,18 @@ if (bindings == null) throw new Error("No Bindings!");
         }
         bindings = bindings.withUnboundVariable(name);
 
-        Type[] bounds = var.getBounds();
+        final Type[] bounds;
+
+        // 15-Jan-2019, tatu: As weird as this looks, apparently on some platforms (Arm CPU, mobile
+        //    devices), unsynchronized internal access can lead to issues, see:
+        //
+        //  https://vmlens.com/articles/java-lang-reflect-typevariable-getbounds-is-not-thread-safe/  
+        //
+        //    No good way to reproduce but since this should not be on critical path, let's add
+        //    syncing as it seems potentially necessary.
+        synchronized (var) {
+            bounds = var.getBounds();
+        }
         return _fromAny(context, bounds[0], bindings);
     }
 
