@@ -6,11 +6,13 @@ import java.lang.annotation.Annotation;
 import java.lang.reflect.*;
 import java.util.*;
 
+import com.fasterxml.jackson.core.JacksonException;
 import com.fasterxml.jackson.core.JsonGenerator;
-import com.fasterxml.jackson.core.JsonProcessingException;
+
 import com.fasterxml.jackson.databind.DeserializationContext;
 import com.fasterxml.jackson.databind.JavaType;
 import com.fasterxml.jackson.databind.JsonMappingException;
+import com.fasterxml.jackson.databind.PropertyName;
 import com.fasterxml.jackson.databind.annotation.JacksonStdImpl;
 
 public final class ClassUtil
@@ -82,12 +84,15 @@ public final class ClassUtil
      * Method for finding all super classes (but not super interfaces) of given class,
      * starting with the immediate super class and ending in the most distant one.
      * Class itself is included if <code>addClassItself</code> is true.
+     *<p>
+     * NOTE: mostly/only called to resolve mix-ins as that's where we do not care
+     * about fully-resolved types, just associated annotations.
      *
      * @since 2.7
      */
     public static List<Class<?>> findSuperClasses(Class<?> cls, Class<?> endBefore,
             boolean addClassItself) {
-        List<Class<?>> result = new LinkedList<Class<?>>();
+        List<Class<?>> result = new ArrayList<Class<?>>(8);
         if ((cls != null) && (cls != endBefore))  {
             if (addClassItself) {
                 result.add(cls);
@@ -166,7 +171,7 @@ public final class ClassUtil
         if (type.isArray()) {
             return "array";
         }
-        if (type.isEnum()) {
+        if (Enum.class.isAssignableFrom(type)) {
             return "enum";
         }
         if (type.isPrimitive()) {
@@ -181,23 +186,24 @@ public final class ClassUtil
     {
         /* As per [JACKSON-187], GAE seems to throw SecurityExceptions
          * here and there... and GAE itself has a bug, too
-         * (see []). Bah. So we need to catch some wayward exceptions on GAE
+         * Bah. So we need to catch some wayward exceptions on GAE
          */
         try {
+            final boolean isStatic = Modifier.isStatic(type.getModifiers());
+
             // one more: method locals, anonymous, are not good:
-            if (hasEnclosingMethod(type)) {
+            // 23-Jun-2020, tatu: [databind#2758] With JDK14+ should allow
+            //    local Record types, however
+            if (!isStatic && hasEnclosingMethod(type)) {
                 return "local/anonymous";
             }
-            
             /* But how about non-static inner classes? Can't construct
              * easily (theoretically, we could try to check if parent
              * happens to be enclosing... but that gets convoluted)
              */
             if (!allowNonStatic) {
-                if (!Modifier.isStatic(type.getModifiers())) {
-                    if (getEnclosingClass(type) != null) {
-                        return "non-static member class";
-                    }
+                if (!isStatic && getEnclosingClass(type) != null) {
+                    return "non-static member class";
                 }
             }
         }
@@ -212,19 +218,18 @@ public final class ClassUtil
     public static Class<?> getOuterClass(Class<?> type)
     {
         // as above, GAE has some issues...
-        try {
-            // one more: method locals, anonymous, are not good:
-            if (hasEnclosingMethod(type)) {
-                return null;
-            }
-            if (!Modifier.isStatic(type.getModifiers())) {
+        if (!Modifier.isStatic(type.getModifiers())) {
+            try {
+                // one more: method locals, anonymous, are not good:
+                if (hasEnclosingMethod(type)) {
+                    return null;
+                }
                 return getEnclosingClass(type);
-            }
-        } catch (SecurityException e) { }
+            } catch (SecurityException e) { }
+        }
         return null;
     }
-    
-    
+
     /**
      * Helper method used to weed out dynamic Proxy types; types that do
      * not expose concrete method API that we could use to figure out
@@ -278,9 +283,14 @@ public final class ClassUtil
                 || cls == com.fasterxml.jackson.databind.annotation.NoClass.class);
     }
 
-    public static boolean isNonStaticInnerClass(Class<?> cls) {
-        return !Modifier.isStatic(cls.getModifiers())
-                && (getEnclosingClass(cls) != null);
+    /**
+     * Helper method for detecting Java14-added new {@code Record} types
+     *
+     * @since 2.12
+     */
+    public static boolean isRecordType(Class<?> cls) {
+        Class<?> parent = cls.getSuperclass();
+        return (parent != null) && "java.lang.Record".equals(parent.getName());
     }
 
     /**
@@ -443,9 +453,8 @@ public final class ClassUtil
         if (e0 instanceof JsonMappingException) {
             throw (JsonMappingException) e0;
         }
-        JsonMappingException e = JsonMappingException.from(ctxt, e0.getMessage());
-        e.initCause(e0);
-        throw e;
+        throw JsonMappingException.from(ctxt, e0.getMessage())
+            .withCause(e0);
     }
 
     /**
@@ -654,7 +663,7 @@ public final class ClassUtil
     /* Type name, name, desc handling methods
     /**********************************************************
      */
-    
+
     /**
      * Helper method used to construct appropriate description
      * when passed either type (Class) or an instance; in latter
@@ -670,6 +679,27 @@ public final class ClassUtil
         return nameOf(cls);
     }
 
+    /**
+     * Helper method to create and return "backticked" description of given
+     * resolved type (or, {@code "null"} if {@code null} passed), similar
+     * to return vaue of {@link #getClassDescription(Object)}.
+     *
+     * @param fullType Fully resolved type or null
+     * @return String description of type including generic type parameters, surrounded
+     *   by backticks, if type passed; or string "null" if {code null} passed
+     *
+     * @since 2.10
+     */
+    public static String getTypeDescription(JavaType fullType)
+    {
+        if (fullType == null) {
+            return "[null]";
+        }
+        StringBuilder sb = new StringBuilder(80).append('`');
+        sb.append(fullType.toCanonical());
+        return sb.append('`').toString();
+    }
+
     /**
      * Helper method used to construct appropriate description
      * when passed either type (Class) or an instance; in latter
@@ -681,7 +711,8 @@ public final class ClassUtil
         if (inst == null) {
             return "[null]";
         }
-        return nameOf(inst.getClass());
+        Class<?> raw = (inst instanceof Class<?>) ? (Class<?>) inst : inst.getClass();
+        return nameOf(raw);
     }
 
     /**
@@ -711,8 +742,11 @@ public final class ClassUtil
     }
 
     /**
-     * Returns either backtick-quoted `named.getName()` (if `named` not null),
-     * or "[null]" if `named` is null.
+     * Returns either single-quoted (apostrophe) {@code 'named.getName()'} (if {@code named} not null),
+     * or "[null]" if {@code named} is null.
+     *<p>
+     * NOTE: before 2.12 returned "backticked" version instead of single-quoted name; changed
+     * to be compatible with most existing quoting usage within databind
      *
      * @since 2.9
      */
@@ -720,17 +754,44 @@ public final class ClassUtil
         if (named == null) {
             return "[null]";
         }
-        return backticked(named.getName());
+        return apostrophed(named.getName());
+    }
+
+    /**
+     * Returns either single-quoted (apostrophe) {@code 'name'} (if {@code name} not null),
+     * or "[null]" if {@code name} is null.
+     *
+     * @since 2.12
+     */
+    public static String name(String name) {
+        if (name == null) {
+            return "[null]";
+        }
+        return apostrophed(name);
+    }
+    
+    /**
+     * Returns either single-quoted (apostrophe) {@code 'name'} (if {@code name} not null),
+     * or "[null]" if {@code name} is null.
+     *
+     * @since 2.12
+     */
+    public static String name(PropertyName name) {
+        if (name == null) {
+            return "[null]";
+        }
+        // 26-Aug-2020, tatu: Should we consider namespace somehow?
+        return apostrophed(name.getSimpleName());
     }
 
     /*
     /**********************************************************
-    /* Other escaping, description acces
+    /* Other escaping, description access
     /**********************************************************
      */
-    
+
     /**
-     * Returns either `text` or [null].
+     * Returns either {@code `text`} (backtick-quoted) or {@code [null]}.
      *
      * @since 2.9
      */
@@ -741,28 +802,44 @@ public final class ClassUtil
         return new StringBuilder(text.length()+2).append('`').append(text).append('`').toString();
     }
 
+    /**
+     * Returns either {@code 'text'} (single-quoted) or {@code [null]}.
+     *
+     * @since 2.9
+     */
+    public static String apostrophed(String text) {
+        if (text == null) {
+            return "[null]";
+        }
+        return new StringBuilder(text.length()+2).append('\'').append(text).append('\'').toString();
+    }
+
     /**
      * Helper method that returns {@link Throwable#getMessage()} for all other exceptions
-     * except for {@link JsonProcessingException}, for which {@code getOriginalMessage()} is
-     * returned instead.
+     * except for (a) {@link JacksonException}, for which {@code getOriginalMessage()} is
+     * returned, and (b) {@link InvocationTargetException}, for which the cause's message
+     * is returned, if available.
      * Method is used to avoid accidentally including trailing location information twice
      * in message when wrapping exceptions.
      *
      * @since 2.9.7
      */
     public static String exceptionMessage(Throwable t) {
-        if (t instanceof JsonProcessingException) {
-            return ((JsonProcessingException) t).getOriginalMessage();
+        if (t instanceof JacksonException) {
+            return ((JacksonException) t).getOriginalMessage();
+        }
+        if (t instanceof InvocationTargetException && t.getCause() != null) {
+            return t.getCause().getMessage();
         }
         return t.getMessage();
     }
-    
+
     /*
     /**********************************************************
     /* Primitive type support
     /**********************************************************
      */
-    
+
     /**
      * Helper method used to get default value for wrappers used for primitive types
      * (0 for Integer etc)
@@ -798,7 +875,9 @@ public final class ClassUtil
 
     /**
      * Helper method for finding wrapper type for given primitive type (why isn't
-     * there one in JDK?)
+     * there one in JDK?).
+     * NOTE: throws {@link IllegalArgumentException} if given type is NOT primitive
+     * type (caller has to check).
      */
     public static Class<?> wrapperType(Class<?> primitiveType)
     {
@@ -831,7 +910,7 @@ public final class ClassUtil
 
     /**
      * Method that can be used to find primitive type for given class if (but only if)
-     * it is either wrapper type or primitive type; returns `null` if type is neither.
+     * it is either wrapper type or primitive type; returns {@code null} if type is neither.
      *
      * @since 2.7
      */
@@ -893,33 +972,46 @@ public final class ClassUtil
      * is done by calling {@link AccessibleObject#setAccessible(boolean)}.
      * 
      * @param member Accessor to call <code>setAccessible()</code> on.
-     * @param force Whether to always try to make accessor accessible (true),
-     *   or only if needed as per access rights (false)
+     * @param evenIfAlreadyPublic Whether to always try to make accessor
+     *   accessible, even if {@code public} (true),
+     *   or only if needed to force by-pass of non-{@code public} access (false)
      *
      * @since 2.7
      */
-    public static void checkAndFixAccess(Member member, boolean force)
+    public static void checkAndFixAccess(Member member, boolean evenIfAlreadyPublic)
     {
         // We know all members are also accessible objects...
         AccessibleObject ao = (AccessibleObject) member;
 
-        /* 14-Jan-2009, tatu: It seems safe and potentially beneficial to
-         *   always to make it accessible (latter because it will force
-         *   skipping checks we have no use for...), so let's always call it.
-         */
+        // 14-Jan-2009, tatu: It seems safe and potentially beneficial to
+        //   always to make it accessible (latter because it will force
+        //   skipping checks we have no use for...), so let's always call it.
         try {
-            if (force || 
-                    (!Modifier.isPublic(member.getModifiers())
-                            || !Modifier.isPublic(member.getDeclaringClass().getModifiers()))) {
+            // 15-Apr-2021, tatu: With JDK 14+ we will be hitting access limitations
+            //    esp. wrt JDK types so let's change a bit
+            final Class<?> declaringClass = member.getDeclaringClass();
+            boolean isPublic = Modifier.isPublic(member.getModifiers())
+                    && Modifier.isPublic(declaringClass.getModifiers());
+            if (!isPublic || (evenIfAlreadyPublic && !isJDKClass(declaringClass))) {
                 ao.setAccessible(true);
             }
         } catch (SecurityException se) {
-            // 17-Apr-2009, tatu: Related to [JACKSON-101]: this can fail on platforms like
+            // 17-Apr-2009, tatu: This can fail on platforms like
             // Google App Engine); so let's only fail if we really needed it...
             if (!ao.isAccessible()) {
                 Class<?> declClass = member.getDeclaringClass();
                 throw new IllegalArgumentException("Cannot access "+member+" (from class "+declClass.getName()+"; failed to set access: "+se.getMessage());
             }
+            // 14-Apr-2021, tatu: [databind#3118] Java 9/JPMS causes new fails...
+            //    But while our baseline is Java 8, must check name
+        } catch (RuntimeException se) {
+            if ("InaccessibleObjectException".equals(se.getClass().getSimpleName())) {
+                throw new IllegalArgumentException(String.format(
+"Failed to call `setAccess()` on %s '%s' due to `%s`, problem: %s",
+member.getClass().getSimpleName(), member.getName(), se.getClass().getName(), se.getMessage()),
+                        se);
+            }
+            throw se;
         }
     }
 
@@ -929,6 +1021,16 @@ public final class ClassUtil
     /**********************************************************
      */
 
+    /**
+     * Helper method that encapsulates reliable check on whether
+     * given raw type "is an Enum", that is, is or extends {@link java.lang.Enum}.
+     *
+     * @since 2.10.1
+     */
+    public static boolean isEnumType(Class<?> rawType) {
+        return Enum.class.isAssignableFrom(rawType);
+    }
+
     /**
      * Helper method that can be used to dynamically figure out
      * enumeration type of given {@link EnumSet}, without having
@@ -966,15 +1068,10 @@ public final class ClassUtil
      * class of enum instance (for "simple" enumerations), or its
      * superclass (for enums with instance fields or methods)
      */
-    @SuppressWarnings("unchecked")
     public static Class<? extends Enum<?>> findEnumType(Enum<?> en)
     {
         // enums with "body" are sub-classes of the formal type
-    	Class<?> ec = en.getClass();
-    	if (ec.getSuperclass() != Enum.class) {
-    	    ec = ec.getSuperclass();
-    	}
-    	return (Class<? extends Enum<?>>) ec;
+        return en.getDeclaringClass();
     }
 
     /**
@@ -1006,7 +1103,7 @@ public final class ClassUtil
      */
     public static <T extends Annotation> Enum<?> findFirstAnnotatedEnumValue(Class<Enum<?>> enumClass, Class<T> annotationClass)
     {
-        Field[] fields = getDeclaredFields(enumClass);
+        Field[] fields = enumClass.getDeclaredFields();
         for (Field field : fields) {
             if (field.isEnumConstant()) {
                 Annotation defaultValueAnnotation = field.getAnnotation(annotationClass);
@@ -1024,9 +1121,9 @@ public final class ClassUtil
     }
 
     /*
-    /**********************************************************
-    /* Jackson-specific stuff
-    /**********************************************************
+    /**********************************************************************
+    /* Methods for detecting special class categories
+    /**********************************************************************
      */
 
     /**
@@ -1047,6 +1144,24 @@ public final class ClassUtil
         return (implClass.getAnnotation(JacksonStdImpl.class) != null);
     }
 
+    /**
+     * Accessor for checking whether given {@code Class} is under Java package
+     * of {@code java.*} or {@code javax.*} (including all sub-packages).
+     *<p>
+     * Added since some aspects of handling need to be changed for JDK types (and
+     * possibly some extensions under {@code javax.}?): for example, forcing of access
+     * will not work well for future JDKs (12 and later).
+     *<p>
+     * Note: in Jackson 2.11 only returned true for {@code java.*} (and not {@code javax.*});
+     * was changed in 2.12.
+     *
+     * @since 2.11
+     */
+    public static boolean isJDKClass(Class<?> rawType) {
+        final String clsName = rawType.getName();
+        return clsName.startsWith("java.") || clsName.startsWith("javax.");
+    }
+
     /*
     /**********************************************************
     /* Access to various Class definition aspects; possibly
@@ -1056,9 +1171,17 @@ public final class ClassUtil
     /**********************************************************
      */
 
+    public static boolean isNonStaticInnerClass(Class<?> cls) {
+        return !Modifier.isStatic(cls.getModifiers())
+                && (getEnclosingClass(cls) != null);
+    }
+
     /**
      * @since 2.7
+     *
+     * @deprecated Since 2.12 (just call methods directly or check class name)
      */
+    @Deprecated // since 2.12
     public static String getPackageName(Class<?> cls) {
         Package pkg = cls.getPackage();
         return (pkg == null) ? null : pkg.getName();
@@ -1072,15 +1195,17 @@ public final class ClassUtil
     }
 
     /**
-     * @since 2.7
+     * @deprecated since 2.11 (just call Class method directly)
      */
+    @Deprecated
     public static Field[] getDeclaredFields(Class<?> cls) {
         return cls.getDeclaredFields();
     }
 
     /**
-     * @since 2.7
+     * @deprecated since 2.11 (just call Class method directly)
      */
+    @Deprecated
     public static Method[] getDeclaredMethods(Class<?> cls) {
         return cls.getDeclaredMethods();
     }
@@ -1105,25 +1230,41 @@ public final class ClassUtil
     public static Method[] getClassMethods(Class<?> cls)
     {
         try {
-            return ClassUtil.getDeclaredMethods(cls);
+            return cls.getDeclaredMethods();
         } catch (final NoClassDefFoundError ex) {
             // One of the methods had a class that was not found in the cls.getClassLoader.
             // Maybe the developer was nice and has a different class loader for this context.
             final ClassLoader loader = Thread.currentThread().getContextClassLoader();
             if (loader == null){
                 // Nope... this is going to end poorly
-                throw ex;
+                return _failGetClassMethods(cls, ex);
             }
             final Class<?> contextClass;
             try {
                 contextClass = loader.loadClass(cls.getName());
             } catch (ClassNotFoundException e) {
                 ex.addSuppressed(e);
-                throw ex;
+                return _failGetClassMethods(cls, ex);
             }
-            return contextClass.getDeclaredMethods(); // Cross fingers
+            try {
+                return contextClass.getDeclaredMethods(); // Cross fingers
+            } catch (Throwable t) {
+                return _failGetClassMethods(cls, t);
+            }
+        } catch (Throwable t) {
+            return _failGetClassMethods(cls, t);
         }
     }
+
+    // @since 2.11.4 (see [databind#2807])
+    private static Method[] _failGetClassMethods(Class<?> cls, Throwable rootCause)
+            throws IllegalArgumentException
+    {
+        throw new IllegalArgumentException(String.format(
+"Failed on call to `getDeclaredMethods()` on class `%s`, problem: (%s) %s",
+cls.getName(), rootCause.getClass().getName(), rootCause.getMessage()),
+                rootCause);
+    }
     
     /**
      * @since 2.7
@@ -1195,12 +1336,34 @@ public final class ClassUtil
 
         private final Field enumSetTypeField;
         private final Field enumMapTypeField;
-    	
+
+        private final String failForEnumSet;
+        private final String failForEnumMap;
+
         private EnumTypeLocator() {
             //JDK uses following fields to store information about actual Enumeration
             // type for EnumSets, EnumMaps...
-    	        enumSetTypeField = locateField(EnumSet.class, "elementType", Class.class);
-    	        enumMapTypeField = locateField(EnumMap.class, "elementType", Class.class);
+
+            Field f = null;
+            String msg = null;
+
+            try {
+                f = locateField(EnumSet.class, "elementType", Class.class);
+            } catch (Exception e) {
+                msg = e.toString();
+            }
+            enumSetTypeField = f;
+            failForEnumSet = msg;
+
+            f = null;
+            msg = null;
+            try {
+                f = locateField(EnumMap.class, "keyType", Class.class);
+            } catch (Exception e) {
+                msg  = e.toString();
+            }
+            enumMapTypeField = f;
+            failForEnumMap = msg;
         }
 
         @SuppressWarnings("unchecked")
@@ -1209,7 +1372,8 @@ public final class ClassUtil
             if (enumSetTypeField != null) {
                 return (Class<? extends Enum<?>>) get(set, enumSetTypeField);
             }
-            throw new IllegalStateException("Cannot figure out type for EnumSet (odd JDK platform?)");
+            throw new IllegalStateException(
+"Cannot figure out type parameter for `EnumSet` (odd JDK platform?), problem: "+failForEnumSet);
         }
 
         @SuppressWarnings("unchecked")
@@ -1218,9 +1382,10 @@ public final class ClassUtil
             if (enumMapTypeField != null) {
                 return (Class<? extends Enum<?>>) get(set, enumMapTypeField);
             }
-            throw new IllegalStateException("Cannot figure out type for EnumMap (odd JDK platform?)");
+            throw new IllegalStateException(
+"Cannot figure out type parameter for `EnumMap` (odd JDK platform?), problem: "+failForEnumMap);
         }
-    	
+
         private Object get(Object bean, Field field)
         {
             try {
@@ -1229,34 +1394,22 @@ public final class ClassUtil
                 throw new IllegalArgumentException(e);
             }
         }
-    	
+
         private static Field locateField(Class<?> fromClass, String expectedName, Class<?> type)
+            throws Exception
         {
-            Field found = null;
     	        // First: let's see if we can find exact match:
-            Field[] fields = getDeclaredFields(fromClass);
-    	        for (Field f : fields) {
-    	            if (expectedName.equals(f.getName()) && f.getType() == type) {
-    	                found = f;
-    	                break;
-    	            }
-    	        }
-    	        // And if not, if there is just one field with the type, that field
-    	        if (found == null) {
-    	            for (Field f : fields) {
-    	                if (f.getType() == type) {
-    	                    // If more than one, can't choose
-    	                    if (found != null) return null;
-    	                    found = f;
-    	                }
-    	            }
-    	        }
-    	        if (found != null) { // it's non-public, need to force accessible
-    	            try {
-    	                found.setAccessible(true);
-    	            } catch (Throwable t) { }
-    	        }
-    	        return found;
+            Field[] fields = fromClass.getDeclaredFields();
+            for (Field f : fields) {
+                if (!expectedName.equals(f.getName()) || f.getType() != type) {
+                    continue;
+                }
+                f.setAccessible(true);
+                return f;
+            }
+            // If not found, indicate with exception
+            throw new IllegalStateException(String.format(
+"No field named '%s' in class '%s'", expectedName, fromClass.getTypeName()));
         }
     }
 
@@ -1276,9 +1429,9 @@ public final class ClassUtil
     {
         public final Constructor<?> _ctor;
 
-        private Annotation[] _annotations;
+        private transient Annotation[] _annotations;
 
-        private  Annotation[][] _paramAnnotations;
+        private transient Annotation[][] _paramAnnotations;
         
         private int _paramCount = -1;
         
