@@ -8,10 +8,12 @@ import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
 
 import com.fasterxml.jackson.core.*;
+import com.fasterxml.jackson.core.exc.StreamReadException;
 import com.fasterxml.jackson.core.json.JsonReadFeature;
 
 import com.fasterxml.jackson.databind.cfg.ContextAttributes;
 import com.fasterxml.jackson.databind.deser.DeserializationProblemHandler;
+import com.fasterxml.jackson.databind.exc.InvalidDefinitionException;
 import com.fasterxml.jackson.databind.exc.MismatchedInputException;
 import com.fasterxml.jackson.databind.json.JsonMapper;
 import com.fasterxml.jackson.databind.node.ArrayNode;
@@ -127,7 +129,8 @@ public class ObjectReaderTest extends BaseMapTest
         try {
             reader.without(JsonReadFeature.ALLOW_JAVA_COMMENTS).readValue(JSON);
             fail("Should not have passed");
-        } catch (JsonProcessingException e) {
+        } catch (DatabindException e) {
+            // DatabindException since it gets wrapped
             verifyException(e, "foo");
         }
     }
@@ -136,14 +139,14 @@ public class ObjectReaderTest extends BaseMapTest
     {
         String FIELD = "a\tb";
         String VALUE = "\t";
-        String JSON = "{ "+quote(FIELD)+" : "+quote(VALUE)+"}";
+        String JSON = "{ "+q(FIELD)+" : "+q(VALUE)+"}";
         Map<?, ?> result;
 
         // First: by default, unescaped control characters should not work
         try {
             result = MAPPER.readValue(JSON, Map.class);
             fail("Should not pass with defaylt settings");
-        } catch (JsonParseException e) {
+        } catch (StreamReadException e) {
             verifyException(e, "Illegal unquoted character");
         }
 
@@ -387,7 +390,7 @@ public class ObjectReaderTest extends BaseMapTest
     // [databind#1637]
     public void testPointerWithArrays() throws Exception
     {
-        final String json = aposToQuotes("{\n'wrapper1': {\n" +
+        final String json = a2q("{\n'wrapper1': {\n" +
                 "  'set1': ['one', 'two', 'three'],\n" +
                 "  'set2': ['four', 'five', 'six']\n" +
                 "},\n" +
@@ -444,8 +447,13 @@ public class ObjectReaderTest extends BaseMapTest
         ObjectReader r = MAPPER.readerFor(String.class);
         List<?> list = r.treeToValue(n, List.class);
         assertEquals(1, list.size());
+
+        // since 2.13:
+        String[] arr = r.treeToValue(n, MAPPER.constructType(String[].class));
+        assertEquals(1, arr.length);
+        assertEquals("xyz", arr[0]);
     }
-    
+
     public void testCodecUnsupportedWrites() throws Exception
     {
         ObjectReader r = MAPPER.readerFor(String.class);
@@ -478,7 +486,7 @@ public class ObjectReaderTest extends BaseMapTest
         try {
             r.readValue("1");
             fail("Should not pass");
-        } catch (JsonMappingException e) {
+        } catch (InvalidDefinitionException e) {
             verifyException(e, "No value type configured");
         }
     }
@@ -493,7 +501,7 @@ public class ObjectReaderTest extends BaseMapTest
         try {
             // but not schema that doesn't match format (no schema exists for json)
             r = r.with(new BogusSchema())
-                .readValue(quote("foo"));
+                .readValue(q("foo"));
             
             fail("Should not pass");
         } catch (IllegalArgumentException e) {
