@@ -40,7 +40,7 @@ public class TestFormatSchema extends BaseMapTest
         private static final long serialVersionUID = 1L;
         @Override
         protected JsonParser _createParser(Reader r, IOContext ctxt)
-            throws IOException, JsonParseException
+            throws IOException
         {
             return new ParserWithSchema(ctxt, _parserFeatures);
         }
@@ -76,7 +76,7 @@ public class TestFormatSchema extends BaseMapTest
         }
 
         @Override
-        protected void _finishString() throws IOException, JsonParseException { }
+        protected void _finishString() throws IOException { }
 
         @Override
         public byte[] getBinaryValue(Base64Variant b64variant) {
@@ -89,7 +89,7 @@ public class TestFormatSchema extends BaseMapTest
         }
 
         @Override
-        public String getText() throws IOException, JsonParseException {
+        public String getText() throws IOException {
             return null;
         }
 
@@ -99,17 +99,17 @@ public class TestFormatSchema extends BaseMapTest
         }
 
         @Override
-        public int getTextLength() throws IOException, JsonParseException {
+        public int getTextLength() throws IOException {
             return 0;
         }
 
         @Override
-        public int getTextOffset() throws IOException, JsonParseException {
+        public int getTextOffset() throws IOException {
             return 0;
         }
 
         @Override
-        public JsonToken nextToken() throws IOException, JsonParseException {
+        public JsonToken nextToken() throws IOException {
             return null;
         }
 
@@ -163,7 +163,7 @@ public class TestFormatSchema extends BaseMapTest
         public void writeFieldName(String name) throws IOException { }
 
         @Override
-        public void writeNull() throws IOException, JsonGenerationException { }
+        public void writeNull() throws IOException { }
 
         @Override
         public void writeNumber(short v) throws IOException { }
@@ -217,7 +217,7 @@ public class TestFormatSchema extends BaseMapTest
         public void writeStartArray() { }
 
         @Override
-        public void writeEndArray() throws IOException, JsonGenerationException { }
+        public void writeEndArray() throws IOException { }
 
         @Override
         public void writeStartObject() { }
