@@ -215,7 +215,7 @@ public class BuilderWithUnwrappedTest extends BaseMapTest
      */
 
     public void testWithUnwrappedAndCreatorSingleParameterAtBeginning() throws Exception {
-        final String json = aposToQuotes("{'person_id':1234,'first_name':'John','last_name':'Doe','years_old':30,'living':true}");
+        final String json = a2q("{'person_id':1234,'first_name':'John','last_name':'Doe','years_old':30,'living':true}");
 
         final ObjectMapper mapper = new ObjectMapper();
         Person person = mapper.readValue(json, Person.class);
@@ -228,7 +228,7 @@ public class BuilderWithUnwrappedTest extends BaseMapTest
     }
 
     public void testWithUnwrappedAndCreatorSingleParameterInMiddle() throws Exception {
-        final String json = aposToQuotes("{'first_name':'John','last_name':'Doe','person_id':1234,'years_old':30,'living':true}");
+        final String json = a2q("{'first_name':'John','last_name':'Doe','person_id':1234,'years_old':30,'living':true}");
 
         final ObjectMapper mapper = new ObjectMapper();
         Person person = mapper.readValue(json, Person.class);
@@ -241,7 +241,7 @@ public class BuilderWithUnwrappedTest extends BaseMapTest
     }
 
     public void testWithUnwrappedAndCreatorSingleParameterAtEnd() throws Exception {
-        final String json = aposToQuotes("{'first_name':'John','last_name':'Doe','years_old':30,'living':true,'person_id':1234}");
+        final String json = a2q("{'first_name':'John','last_name':'Doe','years_old':30,'living':true,'person_id':1234}");
 
         final ObjectMapper mapper = new ObjectMapper();
         Person person = mapper.readValue(json, Person.class);
@@ -254,7 +254,7 @@ public class BuilderWithUnwrappedTest extends BaseMapTest
     }
 
     public void testWithUnwrappedAndCreatorMultipleParametersAtBeginning() throws Exception {
-        final String json = aposToQuotes("{'animal_id':1234,'living':true,'first_name':'John','last_name':'Doe','years_old':30}");
+        final String json = a2q("{'animal_id':1234,'living':true,'first_name':'John','last_name':'Doe','years_old':30}");
 
         final ObjectMapper mapper = new ObjectMapper();
         Animal animal = mapper.readValue(json, Animal.class);
@@ -267,7 +267,7 @@ public class BuilderWithUnwrappedTest extends BaseMapTest
     }
 
     public void testWithUnwrappedAndCreatorMultipleParametersInMiddle() throws Exception {
-        final String json = aposToQuotes("{'first_name':'John','animal_id':1234,'last_name':'Doe','living':true,'years_old':30}");
+        final String json = a2q("{'first_name':'John','animal_id':1234,'last_name':'Doe','living':true,'years_old':30}");
 
         final ObjectMapper mapper = new ObjectMapper();
         Animal animal = mapper.readValue(json, Animal.class);
@@ -280,7 +280,7 @@ public class BuilderWithUnwrappedTest extends BaseMapTest
     }
 
     public void testWithUnwrappedAndCreatorMultipleParametersAtEnd() throws Exception {
-        final String json = aposToQuotes("{'first_name':'John','last_name':'Doe','years_old':30,'living':true,'animal_id':1234}");
+        final String json = a2q("{'first_name':'John','last_name':'Doe','years_old':30,'living':true,'animal_id':1234}");
 
         final ObjectMapper mapper = new ObjectMapper();
         Animal animal = mapper.readValue(json, Animal.class);
@@ -293,7 +293,7 @@ public class BuilderWithUnwrappedTest extends BaseMapTest
     }
 
     public void testWithUnwrappedNoCreator() throws Exception {
-        final String json = aposToQuotes("{'first_name':'John','last_name':'Doe','years_old':'30','animal_id':1234}");
+        final String json = a2q("{'first_name':'John','last_name':'Doe','years_old':'30','animal_id':1234}");
 
         final ObjectMapper mapper = new ObjectMapper();
         AnimalNoCreator animal = mapper.readValue(json, AnimalNoCreator.class);
