@@ -8,6 +8,7 @@ import com.fasterxml.jackson.core.*;
 import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.deser.DeserializationProblemHandler;
+import com.fasterxml.jackson.databind.exc.MismatchedInputException;
 
 /**
  * Unit tests for checking handling of unknown properties
@@ -15,14 +16,6 @@ import com.fasterxml.jackson.databind.deser.DeserializationProblemHandler;
 public class TestUnknownPropertyDeserialization
     extends BaseMapTest
 {
-    final static String JSON_UNKNOWN_FIELD = "{ \"a\" : 1, \"foo\" : [ 1, 2, 3], \"b\" : -1 }";
-
-    /*
-    /**********************************************************
-    /* Helper classes
-    /**********************************************************
-     */
-
     final static class TestBean
     {
         String _unknown;
@@ -49,7 +42,7 @@ public class TestUnknownPropertyDeserialization
         public boolean handleUnknownProperty(DeserializationContext ctxt,
                 JsonParser jp, JsonDeserializer<?> deserializer,
                 Object bean, String propertyName)
-            throws IOException, JsonProcessingException
+            throws IOException
         {
             // very simple, just to verify that we do see correct token type
             ((TestBean) bean).markUnknown(propertyName+":"+jp.currentToken().toString());
@@ -78,6 +71,33 @@ public class TestUnknownPropertyDeserialization
         public int a;
     }
 
+    @JsonIgnoreProperties(ignoreUnknown=true)
+    static class IgnoreUnknownAnySetter {
+
+        Map<String, Object> props = new HashMap<>();
+        
+        @JsonAnySetter
+        public void addProperty(String key, Object value) {
+            props.put(key, value);
+        }
+
+        @JsonAnyGetter
+        public Map<String, Object> getProperties() {
+            return props;
+        }
+    }
+
+    @JsonIgnoreProperties(ignoreUnknown=true)
+    static class IgnoreUnknownUnwrapped {
+      
+      @JsonUnwrapped
+      UnwrappedChild child;
+      
+      static class UnwrappedChild {
+        public int a, b;
+      }
+    }
+
     @SuppressWarnings("serial")
     @JsonIgnoreProperties({"a", "d"})
     static class IgnoreMap extends HashMap<String,Object> { }
@@ -127,6 +147,8 @@ public class TestUnknownPropertyDeserialization
 
     private final ObjectMapper MAPPER = newJsonMapper();
 
+    final static String JSON_UNKNOWN_FIELD = "{ \"a\" : 1, \"foo\" : [ 1, 2, 3], \"b\" : -1 }";
+    
     /**
      * By default we should just get an exception if an unknown property
      * is encountered
@@ -135,7 +157,8 @@ public class TestUnknownPropertyDeserialization
     {
         try {
             MAPPER.readValue(new StringReader(JSON_UNKNOWN_FIELD), TestBean.class);
-        } catch (JsonMappingException jex) {
+            fail("Should not pass");
+        } catch (MismatchedInputException jex) {
             verifyException(jex, "Unrecognized field \"foo\"");
         }
     }
@@ -182,7 +205,7 @@ public class TestUnknownPropertyDeserialization
         TestBean result = null;
         try {
             result = mapper.readValue(new StringReader(JSON_UNKNOWN_FIELD), TestBean.class);
-        } catch (JsonMappingException jex) {
+        } catch (JacksonException jex) {
             fail("Did not expect a problem, got: "+jex.getMessage());
         }
         assertNotNull(result);
@@ -228,6 +251,21 @@ public class TestUnknownPropertyDeserialization
         assertEquals(-3, result.a);
     }
 
+    public void testAnySetterWithFailOnUnknownDisabled() throws Exception
+    {
+        IgnoreUnknownAnySetter value = MAPPER.readValue("{\"x\":\"y\", \"a\":\"b\"}",  IgnoreUnknownAnySetter.class);
+        assertNotNull(value);
+        assertEquals(2, value.props.size());
+    }
+
+    public void testUnwrappedWithFailOnUnknownDisabled() throws Exception
+    {
+      IgnoreUnknownUnwrapped value = MAPPER.readValue("{\"a\":1, \"b\":2}",  IgnoreUnknownUnwrapped.class);
+      assertNotNull(value);
+      assertEquals(1, value.child.a);
+      assertEquals(2, value.child.b);
+    }
+
     /**
      * Test that verifies that use of {@link JsonIgnore} will add implicit
      * skipping of matching properties.
@@ -242,7 +280,8 @@ public class TestUnknownPropertyDeserialization
         // but "d" is not defined, so should still error
         try {
             MAPPER.readValue("{\"a\":1,\"b\":2,\"c\":3,\"d\":4 }", ImplicitIgnores.class);            
-        } catch (JsonMappingException e) {
+            fail("Should not pass");
+        } catch (MismatchedInputException e) {
             verifyException(e, "Unrecognized field \"d\"");
         }
     }
@@ -274,7 +313,7 @@ public class TestUnknownPropertyDeserialization
         ObjectMapper jsonMapper = newJsonMapper();
         jsonMapper.addHandler(new DeserializationProblemHandler() {
             @Override
-            public boolean handleUnknownProperty(DeserializationContext ctxt, JsonParser p, JsonDeserializer<?> deserializer, Object beanOrClass, String propertyName) throws IOException, JsonProcessingException {
+            public boolean handleUnknownProperty(DeserializationContext ctxt, JsonParser p, JsonDeserializer<?> deserializer, Object beanOrClass, String propertyName) throws IOException {
                 p.skipChildren();
                 return true;
             }
