@@ -108,7 +108,7 @@ public class EnumAltIdTest extends BaseMapTest
 
     public void testEnumDesIgnoringCaseWithLowerCaseContent() throws IOException {
         assertEquals(TestEnum.JACKSON,
-                READER_IGNORE_CASE.forType(TestEnum.class).readValue(quote("jackson")));
+                READER_IGNORE_CASE.forType(TestEnum.class).readValue(q("jackson")));
     }
 
     public void testEnumDesIgnoringCaseWithUpperCaseToString() throws IOException {
@@ -147,7 +147,7 @@ public class EnumAltIdTest extends BaseMapTest
 
     public void testIgnoreCaseViaFormat() throws Exception
     {
-        final String JSON = aposToQuotes("{'value':'ok'}");
+        final String JSON = a2q("{'value':'ok'}");
 
         // should be able to allow on per-case basis:
         EnumBean pojo = READER_DEFAULT.forType(EnumBean.class)
@@ -174,13 +174,13 @@ public class EnumAltIdTest extends BaseMapTest
     // for [databind#2352]
     public void testEnumWithAlias() throws Exception {
         ObjectReader reader = MAPPER.readerFor(MyEnum2352_1.class);
-        MyEnum2352_1 nonAliased = reader.readValue(quote("A"));
+        MyEnum2352_1 nonAliased = reader.readValue(q("A"));
         assertEquals(MyEnum2352_1.A, nonAliased);
-        MyEnum2352_1 singleAlias = reader.readValue(quote("singleAlias"));
+        MyEnum2352_1 singleAlias = reader.readValue(q("singleAlias"));
         assertEquals(MyEnum2352_1.B, singleAlias);
-        MyEnum2352_1 multipleAliases1 = reader.readValue(quote("multipleAliases1"));
+        MyEnum2352_1 multipleAliases1 = reader.readValue(q("multipleAliases1"));
         assertEquals(MyEnum2352_1.C, multipleAliases1);
-        MyEnum2352_1 multipleAliases2 = reader.readValue(quote("multipleAliases2"));
+        MyEnum2352_1 multipleAliases2 = reader.readValue(q("multipleAliases2"));
         assertEquals(MyEnum2352_1.C, multipleAliases2);
     }
 
@@ -188,13 +188,13 @@ public class EnumAltIdTest extends BaseMapTest
     public void testEnumWithAliasAndToStringSupported() throws Exception {
         ObjectReader reader = MAPPER.readerFor(MyEnum2352_2.class)
                 .with(DeserializationFeature.READ_ENUMS_USING_TO_STRING);
-        MyEnum2352_2 nonAliased = reader.readValue(quote("a"));
+        MyEnum2352_2 nonAliased = reader.readValue(q("a"));
         assertEquals(MyEnum2352_2.A, nonAliased);
-        MyEnum2352_2 singleAlias = reader.readValue(quote("singleAlias"));
+        MyEnum2352_2 singleAlias = reader.readValue(q("singleAlias"));
         assertEquals(MyEnum2352_2.B, singleAlias);
-        MyEnum2352_2 multipleAliases1 = reader.readValue(quote("multipleAliases1"));
+        MyEnum2352_2 multipleAliases1 = reader.readValue(q("multipleAliases1"));
         assertEquals(MyEnum2352_2.C, multipleAliases1);
-        MyEnum2352_2 multipleAliases2 = reader.readValue(quote("multipleAliases2"));
+        MyEnum2352_2 multipleAliases2 = reader.readValue(q("multipleAliases2"));
         assertEquals(MyEnum2352_2.C, multipleAliases2);
     }
 
@@ -202,15 +202,15 @@ public class EnumAltIdTest extends BaseMapTest
     public void testEnumWithAliasAndDefaultForUnknownValueEnabled() throws Exception {
         ObjectReader reader = MAPPER.readerFor(MyEnum2352_3.class)
                 .with(DeserializationFeature.READ_UNKNOWN_ENUM_VALUES_USING_DEFAULT_VALUE);
-        MyEnum2352_3 nonAliased = reader.readValue(quote("A"));
+        MyEnum2352_3 nonAliased = reader.readValue(q("A"));
         assertEquals(MyEnum2352_3.A, nonAliased);
-        MyEnum2352_3 singleAlias = reader.readValue(quote("singleAlias"));
+        MyEnum2352_3 singleAlias = reader.readValue(q("singleAlias"));
         assertEquals(MyEnum2352_3.B, singleAlias);
-        MyEnum2352_3 defaulted = reader.readValue(quote("unknownValue"));
+        MyEnum2352_3 defaulted = reader.readValue(q("unknownValue"));
         assertEquals(MyEnum2352_3.B, defaulted);
-        MyEnum2352_3 multipleAliases1 = reader.readValue(quote("multipleAliases1"));
+        MyEnum2352_3 multipleAliases1 = reader.readValue(q("multipleAliases1"));
         assertEquals(MyEnum2352_3.C, multipleAliases1);
-        MyEnum2352_3 multipleAliases2 = reader.readValue(quote("multipleAliases2"));
+        MyEnum2352_3 multipleAliases2 = reader.readValue(q("multipleAliases2"));
         assertEquals(MyEnum2352_3.C, multipleAliases2);
     }
 }
