@@ -4,7 +4,9 @@ import java.io.IOException;
 import java.util.*;
 
 import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
+
 import com.fasterxml.jackson.core.JsonParser;
+
 import com.fasterxml.jackson.databind.*;
 
 /**
@@ -37,12 +39,12 @@ public class ExceptionSerializationTest
     }
 
     /*
-    /**********************************************************
-    /* Tests
-    /**********************************************************
+    /**********************************************************************
+    /* Test methods
+    /**********************************************************************
      */
 
-    private final ObjectMapper MAPPER = new ObjectMapper();
+    private final ObjectMapper MAPPER = newJsonMapper();
 
     public void testSimple() throws Exception
     {
@@ -113,13 +115,13 @@ public class ExceptionSerializationTest
     }
 
     // [databind#1368]
-    public void testJsonMappingExceptionSerialization() throws IOException {
+    public void testDatabindExceptionSerialization() throws IOException {
         Exception e = null;
         // cant deserialize due to unexpected constructor
         try {
             MAPPER.readValue( "{ \"val\": \"foo\" }", NoSerdeConstructor.class );
             fail("Should not pass");
-        } catch (JsonMappingException e0) {
+        } catch (MismatchedInputException e0) {
             verifyException(e0, "cannot deserialize from Object");
             e = e0;
         }
