@@ -3,15 +3,20 @@ package com.fasterxml.jackson.databind.introspect;
 import java.lang.annotation.Annotation;
 import java.util.*;
 
+import com.fasterxml.jackson.annotation.JacksonInject;
+import com.fasterxml.jackson.annotation.JsonIgnore;
 import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
 import com.fasterxml.jackson.annotation.JsonInclude;
 
+import com.fasterxml.jackson.annotation.JsonProperty;
+import com.fasterxml.jackson.annotation.OptBoolean;
 import com.fasterxml.jackson.core.Version;
 
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.cfg.MapperConfig;
 import com.fasterxml.jackson.databind.deser.std.StringDeserializer;
 import com.fasterxml.jackson.databind.deser.std.UntypedObjectDeserializer;
+import com.fasterxml.jackson.databind.json.JsonMapper;
 import com.fasterxml.jackson.databind.jsontype.NamedType;
 import com.fasterxml.jackson.databind.jsontype.TypeResolverBuilder;
 import com.fasterxml.jackson.databind.ser.std.StringSerializer;
@@ -197,6 +202,27 @@ public class IntrospectorPairTest extends BaseMapTest
             return (String) values.get("findTypeName");
         }
 
+        /*
+        /******************************************************
+        /* Serialization introspection
+        /******************************************************
+         */
+
+        @Override
+        public Boolean hasAsKey(MapperConfig<?> config, Annotated a) {
+            return (Boolean) values.get("hasAsKey");
+        }
+
+        @Override
+        public Boolean hasAsValue(Annotated a) {
+            return (Boolean) values.get("hasAsValue");
+        }
+
+        @Override
+        public Boolean hasAnyGetter(Annotated ann) {
+            return (Boolean) values.get("hasAnyGetter");
+        }
+
         /*
         /******************************************************
         /* Deserialization introspection
@@ -378,6 +404,81 @@ public class IntrospectorPairTest extends BaseMapTest
         assertNull(new AnnotationIntrospectorPair(nop2, nop).findSerializer(null));
     }
 
+    public void testHasAsValue() throws Exception
+    {
+        IntrospectorWithMap intr1 = new IntrospectorWithMap()
+                .add("hasAsValue", Boolean.TRUE);
+        IntrospectorWithMap intr2 = new IntrospectorWithMap()
+                .add("hasAsValue", Boolean.FALSE);
+        assertNull(new AnnotationIntrospectorPair(NO_ANNOTATIONS, NO_ANNOTATIONS)
+                .hasAsValue(null));
+        assertEquals(Boolean.TRUE, new AnnotationIntrospectorPair(intr1, NO_ANNOTATIONS)
+                .hasAsValue(null));
+        assertEquals(Boolean.TRUE, new AnnotationIntrospectorPair(NO_ANNOTATIONS, intr1)
+                .hasAsValue(null));
+        assertEquals(Boolean.FALSE, new AnnotationIntrospectorPair(intr2, NO_ANNOTATIONS)
+                .hasAsValue(null));
+        assertEquals(Boolean.FALSE, new AnnotationIntrospectorPair(NO_ANNOTATIONS, intr2)
+                .hasAsValue(null));
+
+        assertEquals(Boolean.TRUE, new AnnotationIntrospectorPair(intr1, intr2)
+                .hasAsValue(null));
+        assertEquals(Boolean.FALSE, new AnnotationIntrospectorPair(intr2, intr1)
+                .hasAsValue(null));
+    }
+
+    public void testHasAsKey() throws Exception
+    {
+        IntrospectorWithMap intr1 = new IntrospectorWithMap()
+                .add("hasAsKey", Boolean.TRUE);
+        IntrospectorWithMap intr2 = new IntrospectorWithMap()
+                .add("hasAsKey", Boolean.FALSE);
+        assertNull(new AnnotationIntrospectorPair(NO_ANNOTATIONS, NO_ANNOTATIONS)
+                .hasAsKey(null, null));
+        assertEquals(Boolean.TRUE, new AnnotationIntrospectorPair(intr1, NO_ANNOTATIONS)
+                .hasAsKey(null, null));
+        assertEquals(Boolean.TRUE, new AnnotationIntrospectorPair(NO_ANNOTATIONS, intr1)
+                .hasAsKey(null, null));
+        assertEquals(Boolean.FALSE, new AnnotationIntrospectorPair(intr2, NO_ANNOTATIONS)
+                .hasAsKey(null, null));
+        assertEquals(Boolean.FALSE, new AnnotationIntrospectorPair(NO_ANNOTATIONS, intr2)
+                .hasAsKey(null, null));
+
+        assertEquals(Boolean.TRUE, new AnnotationIntrospectorPair(intr1, intr2)
+                .hasAsKey(null, null));
+        assertEquals(Boolean.FALSE, new AnnotationIntrospectorPair(intr2, intr1)
+                .hasAsKey(null, null));
+    }
+
+    public void testHasAnyGetter() throws Exception
+    {
+        IntrospectorWithMap intr1 = new IntrospectorWithMap()
+                .add("hasAnyGetter", Boolean.TRUE);
+        IntrospectorWithMap intr2 = new IntrospectorWithMap()
+                .add("hasAnyGetter", Boolean.FALSE);
+        assertNull(new AnnotationIntrospectorPair(NO_ANNOTATIONS, NO_ANNOTATIONS)
+                .hasAnyGetter(null));
+        assertEquals(Boolean.TRUE, new AnnotationIntrospectorPair(intr1, NO_ANNOTATIONS)
+                .hasAnyGetter(null));
+        assertEquals(Boolean.TRUE, new AnnotationIntrospectorPair(NO_ANNOTATIONS, intr1)
+                .hasAnyGetter(null));
+        assertEquals(Boolean.FALSE, new AnnotationIntrospectorPair(intr2, NO_ANNOTATIONS)
+                .hasAnyGetter(null));
+        assertEquals(Boolean.FALSE, new AnnotationIntrospectorPair(NO_ANNOTATIONS, intr2)
+                .hasAnyGetter(null));
+
+        assertEquals(Boolean.TRUE, new AnnotationIntrospectorPair(intr1, intr2)
+                .hasAnyGetter(null));
+        assertEquals(Boolean.FALSE, new AnnotationIntrospectorPair(intr2, intr1)
+                .hasAnyGetter(null));
+    }
+
+    /*
+    /**********************************************************
+    /* Test methods, deser
+    /**********************************************************
+     */
+
     public void testFindDeserializer() throws Exception
     {
         final JsonDeserializer<?> deserString = StringDeserializer.instance;
@@ -505,4 +606,94 @@ public class IntrospectorPairTest extends BaseMapTest
         assertEquals(JsonInclude.Include.NON_EMPTY, v21.getContentInclusion());
         assertEquals(JsonInclude.Include.NON_ABSENT, v21.getValueInclusion());
     }
+
+    /*
+    /**********************************************************
+    /* Introspectors and test for [jackson-modules-base#134]/[databind#962]
+    /**********************************************************
+     */
+    static class TestIntrospector extends NopAnnotationIntrospector {
+        @Override
+        public JacksonInject.Value findInjectableValue(AnnotatedMember m) {
+            if (m.getRawType() == UnreadableBean.class) {
+                return JacksonInject.Value.forId("jjj");
+            }
+            return null;
+        }
+    }
+
+    static class TestInjector extends InjectableValues {
+        @Override
+        public Object findInjectableValue(Object valueId, DeserializationContext ctxt, BeanProperty forProperty, Object beanInstance) {
+            if (valueId == "jjj") {
+                UnreadableBean bean = new UnreadableBean();
+                bean.setValue(1);
+                return bean;
+            }
+            return null;
+        }
+    }
+
+    enum SimpleEnum { ONE, TWO }
+
+    static class UnreadableBean {
+        public SimpleEnum value;
+
+        public void setValue(SimpleEnum value) {
+            this.value = value;
+        }
+
+        public void setValue(Integer intValue) {
+            this.value = SimpleEnum.values()[intValue];
+        }
+
+        public SimpleEnum getValue() {
+            return value;
+        }
+    }
+
+    static class ReadableInjectedBean {
+        public ReadableInjectedBean(@JacksonInject(useInput = OptBoolean.FALSE) UnreadableBean injectBean) {
+            this.injectBean = injectBean;
+        }
+        @JsonProperty
+        String foo;
+        @JsonIgnore
+        UnreadableBean injectBean;
+    }
+
+    static class UnreadableInjectedBean {
+        public UnreadableInjectedBean(@JacksonInject UnreadableBean injectBean) {
+            this.injectBean = injectBean;
+        }
+        @JsonProperty
+        private String foo;
+        @JsonIgnore
+        private UnreadableBean injectBean;
+    }
+
+    public void testMergingIntrospectorsForInjection() throws Exception {
+        AnnotationIntrospector testIntrospector = new TestIntrospector();
+        ObjectMapper mapper = new JsonMapper();
+        mapper.setInjectableValues(new TestInjector());
+        mapper.setAnnotationIntrospectors(
+                new AnnotationIntrospectorPair(testIntrospector,
+                        mapper.getSerializationConfig().getAnnotationIntrospector()),
+                new AnnotationIntrospectorPair(testIntrospector,
+                        mapper.getDeserializationConfig().getAnnotationIntrospector())
+        );
+        ReadableInjectedBean bean = mapper.readValue("{\"foo\": \"bob\"}", ReadableInjectedBean.class);
+        assertEquals("bob", bean.foo);
+        assertEquals(SimpleEnum.TWO, bean.injectBean.value);
+
+        boolean successReadingUnreadableInjectedBean;
+        try {
+            /*UnreadableInjectedBean noBean =*/ mapper.readValue("{\"foo\": \"bob\"}", UnreadableInjectedBean.class);
+            successReadingUnreadableInjectedBean = true;
+        } catch (JsonMappingException e) {
+            successReadingUnreadableInjectedBean = false;
+            assertTrue(e.getMessage().contains("Conflicting setter definitions"));
+        }
+        assertFalse(successReadingUnreadableInjectedBean);
+    }
 }
