@@ -4,6 +4,7 @@ import com.fasterxml.jackson.annotation.JsonTypeInfo;
 
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
+import com.fasterxml.jackson.databind.testutil.NoCheckSubTypeValidator;
 
 public class NoTypeInfoTest extends BaseMapTest
 {
@@ -24,8 +25,9 @@ public class NoTypeInfoTest extends BaseMapTest
 
     public void testWithIdNone() throws Exception
     {
-        final ObjectMapper mapper = newObjectMapper();
-        mapper.enableDefaultTyping();
+        final ObjectMapper mapper = jsonMapperBuilder()
+            .activateDefaultTyping(NoCheckSubTypeValidator.instance)
+            .build();
         // serialize without type info
         String json = mapper.writeValueAsString(new NoType());
         assertEquals("{\"a\":3}", json);
