@@ -8,6 +8,7 @@ import com.fasterxml.jackson.annotation.ObjectIdGenerators;
 
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.ObjectMapper.DefaultTyping;
+import com.fasterxml.jackson.databind.testutil.NoCheckSubTypeValidator;
 
 public class TestObjectIdWithPolymorphic extends BaseMapTest
 {
@@ -134,7 +135,8 @@ public class TestObjectIdWithPolymorphic extends BaseMapTest
         ObjectMapper om = new ObjectMapper();
         om.enable(SerializationFeature.WRITE_ENUMS_USING_INDEX);
         om.enable(SerializationFeature.INDENT_OUTPUT);
-        om.enableDefaultTypingAsProperty(DefaultTyping.NON_FINAL, "@class");
+        om.activateDefaultTypingAsProperty(NoCheckSubTypeValidator.instance,
+                DefaultTyping.NON_FINAL, "@class");
     
         Process p = new Process();
         Scope s = new Scope(p, null);
