@@ -105,7 +105,7 @@ public class SequenceWriterTest extends BaseMapTest
             .writeAll(Arrays.asList(new Bean(5), new Bean(7)))
         ;
         w.close();
-        assertEquals(aposToQuotes("{'a':13}\n{'a':-6}\n{'a':3}\n{'a':1}\n{'a':5}\n{'a':7}"),
+        assertEquals(a2q("{'a':13}\n{'a':-6}\n{'a':3}\n{'a':1}\n{'a':5}\n{'a':7}"),
                 strw.toString());
 
         strw = new StringWriter();
@@ -117,10 +117,27 @@ public class SequenceWriterTest extends BaseMapTest
             .write(new Bean(2));
         w.close();
         gen.close();
-        assertEquals(aposToQuotes("{'a':1}/{'a':2}"),
+        assertEquals(a2q("{'a':1}/{'a':2}"),
                 strw.toString());
     }
 
+    public void testSimpleNonArrayNoSeparator() throws Exception
+    {
+        final String EXP = a2q("{'a':1}{'a':2}");
+
+        // Also, ok to specify no separator
+        StringWriter strw = new StringWriter();
+        try (SequenceWriter seq = WRITER.withRootValueSeparator("")
+                .writeValues(strw)) {
+            seq.write(new Bean(1))
+                .write(new Bean(2));
+        }
+        assertEquals(EXP, strw.toString());
+
+        // 08-Mar-2021, tatu: Note that attempting to set RVS to `null`
+        //   will not work in 2.x.
+    }
+
     public void testSimpleArray() throws Exception
     {
         StringWriter strw = new StringWriter();
@@ -129,7 +146,7 @@ public class SequenceWriterTest extends BaseMapTest
             .write(new Bean(2))
             .writeAll(new Bean[] { new Bean(-7), new Bean(2) });
         w.close();
-        assertEquals(aposToQuotes("[{'a':1},{'a':2},{'a':-7},{'a':2}]"),
+        assertEquals(a2q("[{'a':1},{'a':2},{'a':-7},{'a':2}]"),
                 strw.toString());
 
         strw = new StringWriter();
@@ -141,7 +158,7 @@ public class SequenceWriterTest extends BaseMapTest
             .writeAll((Iterable<Bean>) bean);
         w.close();
         gen.close();
-        assertEquals(aposToQuotes("[{'a':1},null,{'a':3}]"),
+        assertEquals(a2q("[{'a':1},null,{'a':3}]"),
                 strw.toString());
     }
 
@@ -160,7 +177,7 @@ public class SequenceWriterTest extends BaseMapTest
         w.write(new ImplA(3))
             .write(new ImplA(4))
             .close();
-        assertEquals(aposToQuotes("{'type':'A','value':3}\n{'type':'A','value':4}"),
+        assertEquals(a2q("{'type':'A','value':3}\n{'type':'A','value':4}"),
                 strw.toString());
     }
 
@@ -173,7 +190,7 @@ public class SequenceWriterTest extends BaseMapTest
         w.write(new ImplA(-1))
             .write(new ImplA(6))
             .close();
-        assertEquals(aposToQuotes("[{'type':'A','value':-1},{'type':'A','value':6}]"),
+        assertEquals(a2q("[{'type':'A','value':-1},{'type':'A','value':6}]"),
                 strw.toString());
     }
 
@@ -188,7 +205,7 @@ public class SequenceWriterTest extends BaseMapTest
             .write(new ImplA(7));
         w.flush();
         w.close();
-        assertEquals(aposToQuotes("[{'type':'A','value':-1},{'type':'B','b':3},{'type':'A','value':7}]"),
+        assertEquals(a2q("[{'type':'A','value':-1},{'type':'B','b':3},{'type':'A','value':7}]"),
                 strw.toString());
     }
 
@@ -208,7 +225,7 @@ public class SequenceWriterTest extends BaseMapTest
         assertTrue(input.closed);
         seq.close();
         input.close();
-        assertEquals(aposToQuotes("{'closed':false,'x':0}"), out.toString());
+        assertEquals(a2q("{'closed':false,'x':0}"), out.toString());
     }
 
     public void testWithExplicitType() throws Exception
@@ -233,6 +250,6 @@ public class SequenceWriterTest extends BaseMapTest
 
         seq.close();
         seq.flush();
-        assertEquals(aposToQuotes("{'a':1,'b':2} {'a':1} {'a':1}"), out.toString());
+        assertEquals(a2q("{'a':1,'b':2} {'a':1} {'a':1}"), out.toString());
     }
 }
