@@ -509,7 +509,7 @@ public class GenericTypeSerializationTest extends BaseMapTest
         List<Base727> input = new ArrayList<Base727>();
         input.add(new Impl727(1, 2));
 
-        final String EXP = aposToQuotes("[{'a':1,'b':2}]");
+        final String EXP = a2q("[{'a':1,'b':2}]");
         // Without type enforcement, produces expected output:
         assertEquals(EXP, MAPPER.writeValueAsString(input));
         assertEquals(EXP, MAPPER.writer().writeValueAsString(input));
@@ -531,8 +531,8 @@ public class GenericTypeSerializationTest extends BaseMapTest
             list = (List<Entity2821<?>>) (List<?>) foo;
         }
         Wrapper2821 val = new Wrapper2821(list);
-        // Was failing with `com.fasterxml.jackson.databind.JsonMappingException`: Strange Map
-        // type java.util.Map: cannot determine type parameters (through reference chain: ---)
+        // Was failing with exception "Strange Map
+        // type java.util.Map: cannot determine type parameters (through reference chain: ---)"
         String json = MAPPER.writeValueAsString(val);
         assertNotNull(json);
     }
