@@ -8,12 +8,16 @@ import javax.xml.parsers.DocumentBuilderFactory;
 
 import org.w3c.dom.Element;
 
+import com.fasterxml.jackson.annotation.JsonFilter;
 import com.fasterxml.jackson.annotation.JsonFormat;
+import com.fasterxml.jackson.annotation.JsonPropertyOrder;
 import com.fasterxml.jackson.core.*;
 import com.fasterxml.jackson.core.io.CharacterEscapes;
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.annotation.JsonSerialize;
 import com.fasterxml.jackson.databind.module.SimpleModule;
+import com.fasterxml.jackson.databind.ser.impl.SimpleBeanPropertyFilter;
+import com.fasterxml.jackson.databind.ser.impl.SimpleFilterProvider;
 import com.fasterxml.jackson.databind.ser.std.CollectionSerializer;
 import com.fasterxml.jackson.databind.ser.std.StdDelegatingSerializer;
 import com.fasterxml.jackson.databind.ser.std.StdScalarSerializer;
@@ -28,7 +32,7 @@ public class TestCustomSerializers extends BaseMapTest
     static class ElementSerializer extends JsonSerializer<Element>
     {
         @Override
-        public void serialize(Element value, JsonGenerator gen, SerializerProvider provider) throws IOException, JsonProcessingException {
+        public void serialize(Element value, JsonGenerator gen, SerializerProvider provider) throws IOException {
             gen.writeString("element");
         }
     }
@@ -146,11 +150,46 @@ public class TestCustomSerializers extends BaseMapTest
         }
     }
 
+    // [databind#2475]
+    static class MyFilter2475 extends SimpleBeanPropertyFilter {
+        @Override
+        public void serializeAsField(Object pojo, JsonGenerator jgen, SerializerProvider provider, PropertyWriter writer) throws Exception {
+            // Ensure that "current value" remains pojo
+            final JsonStreamContext ctx = jgen.getOutputContext();
+            final Object curr = ctx.getCurrentValue();
+
+            if (!(curr instanceof Item2475)) {
+                throw new Error("Field '"+writer.getName()+"', context not that of `Item2475` instance");
+            }
+            super.serializeAsField(pojo, jgen, provider, writer);
+        }
+    }
+
+    @JsonFilter("myFilter")
+    @JsonPropertyOrder({ "id", "set" })
+    public static class Item2475 {
+        private Collection<String> set;
+        private String id;
+
+        public Item2475(Collection<String> set, String id) {
+            this.set = set;
+            this.id = id;
+        }
+
+        public Collection<String> getSet() {
+            return set;
+        }
+
+        public String getId() {
+            return id;
+        }
+    }
+
     /*
     /**********************************************************
     /* Unit tests
     /**********************************************************
-    */
+     */
 
     private final ObjectMapper MAPPER = new ObjectMapper();
 
@@ -211,19 +250,19 @@ public class TestCustomSerializers extends BaseMapTest
     // [databind#215]: Allow registering CharacterEscapes via ObjectWriter
     public void testCustomEscapes() throws Exception
     {
-        assertEquals(quote("foo\\u0062\\Ar"),
+        assertEquals(q("foo\\u0062\\Ar"),
                 MAPPER.writer(new CustomEscapes()).writeValueAsString("foobar"));
     }
     
     public void testNumberSubclass() throws Exception
     {
-        assertEquals(aposToQuotes("{'x':42}"),
+        assertEquals(a2q("{'x':42}"),
                 MAPPER.writeValueAsString(new LikeNumber(42)));
     }
 
     public void testWithCurrentValue() throws Exception
     {
-        assertEquals(aposToQuotes("{'prop':'Issue631Bean/42'}"),
+        assertEquals(a2q("{'prop':'Issue631Bean/42'}"),
                 MAPPER.writeValueAsString(new Issue631Bean(42)));
     }
 
@@ -231,7 +270,7 @@ public class TestCustomSerializers extends BaseMapTest
     {
         // First variant that uses per-property override
         StringListWrapper wr = new StringListWrapper("a", null, "b");
-        assertEquals(aposToQuotes("{'list':['A',null,'B']}"),
+        assertEquals(a2q("{'list':['A',null,'B']}"),
                 MAPPER.writeValueAsString(wr));
 
         // and then per-type registration
@@ -241,14 +280,29 @@ public class TestCustomSerializers extends BaseMapTest
         ObjectMapper mapper = new ObjectMapper()
                 .registerModule(module);
 
-        assertEquals(quote("FOOBAR"), mapper.writeValueAsString("foobar"));
-        assertEquals(aposToQuotes("['FOO',null]"),
+        assertEquals(q("FOOBAR"), mapper.writeValueAsString("foobar"));
+        assertEquals(a2q("['FOO',null]"),
                 mapper.writeValueAsString(new String[] { "foo", null }));
 
         List<String> list = Arrays.asList("foo", null);
-        assertEquals(aposToQuotes("['FOO',null]"), mapper.writeValueAsString(list));
+        assertEquals(a2q("['FOO',null]"), mapper.writeValueAsString(list));
 
         Set<String> set = new LinkedHashSet<String>(Arrays.asList("foo", null));
-        assertEquals(aposToQuotes("['FOO',null]"), mapper.writeValueAsString(set));
+        assertEquals(a2q("['FOO',null]"), mapper.writeValueAsString(set));
     }
+
+    // [databind#2475]
+    public void testIssue2475() throws Exception {
+        SimpleFilterProvider provider = new SimpleFilterProvider().addFilter("myFilter", new MyFilter2475());
+        ObjectWriter writer = MAPPER.writer(provider);
+
+        // contents don't really matter that much as verification within filter but... let's
+        // check anyway
+        assertEquals(a2q("{'id':'ID-1','set':[]}"),
+                writer.writeValueAsString(new Item2475(new ArrayList<String>(), "ID-1")));
+
+        assertEquals(a2q("{'id':'ID-2','set':[]}"),
+                writer.writeValueAsString(new Item2475(new HashSet<String>(), "ID-2")));
+    }    
+
 }
