@@ -37,6 +37,7 @@ public class TestTokenBuffer extends BaseMapTest
         assertSame(MAPPER, buf.getCodec());
         assertNotNull(buf.getOutputContext());
         assertFalse(buf.isClosed());
+        assertTrue(buf.isEmpty());
 
         buf.setCodec(null);
         assertNull(buf.getCodec());
@@ -57,7 +58,8 @@ public class TestTokenBuffer extends BaseMapTest
     public void testSimpleWrites() throws IOException
     {
         TokenBuffer buf = new TokenBuffer(null, false); // no ObjectCodec
-        
+        assertTrue(buf.isEmpty());
+
         // First, with empty buffer
         JsonParser p = buf.asParser();
         assertNull(p.currentToken());
@@ -66,6 +68,7 @@ public class TestTokenBuffer extends BaseMapTest
 
         // Then with simple text
         buf.writeString("abc");
+        assertFalse(buf.isEmpty());
 
         p = buf.asParser();
         assertNull(p.currentToken());
@@ -531,7 +534,7 @@ public class TestTokenBuffer extends BaseMapTest
         buf.writeNumber((short) 4);
         buf.writeNumber(0.5);
         buf.writeEndArray();
-        assertEquals(aposToQuotes("[true,false,"+l+",4,0.5]"), MAPPER.writeValueAsString(buf));
+        assertEquals(a2q("[true,false,"+l+",4,0.5]"), MAPPER.writeValueAsString(buf));
         buf.close();
 
         buf = new TokenBuffer(MAPPER, false);
@@ -542,7 +545,7 @@ public class TestTokenBuffer extends BaseMapTest
         buf.writeNumber(BigInteger.valueOf(123));
         buf.writeFieldName("dec");
         buf.writeNumber(BigDecimal.valueOf(5).movePointLeft(2));
-        assertEquals(aposToQuotes("{'foo':null,'bar':123,'dec':0.05}"), MAPPER.writeValueAsString(buf));
+        assertEquals(a2q("{'foo':null,'bar':123,'dec':0.05}"), MAPPER.writeValueAsString(buf));
         buf.close();
     }
 
@@ -657,6 +660,7 @@ public class TestTokenBuffer extends BaseMapTest
         TokenBuffer buf = new TokenBuffer(null, false);
         Object inputPojo = new Sub1730();
         buf.writeEmbeddedObject(inputPojo);
+        assertEquals(JsonToken.VALUE_EMBEDDED_OBJECT, buf.firstToken());
 
         // first: raw value won't be transformed in any way:
         JsonParser p = buf.asParser();
@@ -666,4 +670,19 @@ public class TestTokenBuffer extends BaseMapTest
         p.close();
         buf.close();
     }
+
+    public void testIsEmpty() throws Exception
+    {
+        // Let's check that segment boundary won't ruin it
+        try (TokenBuffer buf = new TokenBuffer(null, false)) {
+            assertTrue(buf.isEmpty());
+
+            for (int i = 0; i < 100; ++i) {
+                buf.writeNumber(i);
+                assertFalse(buf.isEmpty());
+            }
+
+            assertEquals(JsonToken.VALUE_NUMBER_INT, buf.firstToken());
+        }
+    }
 }
